UPDATE colors SET scheme = '' WHERE scheme = 0;

INSERT INTO COLORS (number, value, scheme) VALUES (0  , <%- parseInt("base["00"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (1  , <%- parseInt("base["08"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (2  , <%- parseInt("base["0B"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (3  , <%- parseInt("base["0A"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (4  , <%- parseInt("base["0D"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (5  , <%- parseInt("base["0E"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (6  , <%- parseInt("base["0C"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (7  , <%- parseInt("base["05"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (8  , <%- parseInt("base["03"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (9  , <%- parseInt("base["08"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (10 , <%- parseInt("base["0B"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (11 , <%- parseInt("base["0A"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (12 , <%- parseInt("base["0D"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (13 , <%- parseInt("base["0E"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (14 , <%- parseInt("base["0C"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (15 , <%- parseInt("base["07"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (16 , <%- parseInt("base["09"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (17 , <%- parseInt("base["0F"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (18 , <%- parseInt("base["01"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (19 , <%- parseInt("base["02"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (20 , <%- parseInt("base["04"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);
INSERT INTO COLORS (number, value, scheme) VALUES (21 , <%- parseInt("base["06"]["hex"]", 16) - parseInt("010­00000", 16) %> , 0);

UPDATE colorDefaults set fg=7, bg=0 WHERE scheme = 0;
