Windows Registry Editor Version 5.00

; Base16 <%- scheme %> (https://github.com/chriskempson/base16)
; Scheme: <%- author %>

[HKEY_CURRENT_USER\Console]
"ColorTable00"=dword:00<%- base["00"]["hexbgr"] %> ; Black
"ColorTable01"=dword:00<%- base["0D"]["hexbgr"] %> ; Blue
"ColorTable02"=dword:00<%- base["0B"]["hexbgr"] %> ; Green
"ColorTable03"=dword:00<%- base["0C"]["hexbgr"] %> ; Aqua
"ColorTable04"=dword:00<%- base["09"]["hexbgr"] %> ; Red
"ColorTable05"=dword:00<%- base["0E"]["hexbgr"] %> ; Purple
"ColorTable06"=dword:00<%- base["0A"]["hexbgr"] %> ; Yellow
"ColorTable07"=dword:00<%- base["04"]["hexbgr"] %> ; White
"ColorTable08"=dword:00<%- base["03"]["hexbgr"] %> ; Gray
"ColorTable09"=dword:00<%- base["0D"]["hexbgr"] %> ; Light Blue
"ColorTable10"=dword:00<%- base["0B"]["hexbgr"] %> ; Light Green
"ColorTable11"=dword:00<%- base["0C"]["hexbgr"] %> ; Light Aqua
"ColorTable12"=dword:00<%- base["08"]["hexbgr"] %> ; Light Red
"ColorTable13"=dword:00<%- base["0F"]["hexbgr"] %> ; Light Purple
"ColorTable14"=dword:00<%- base["0A"]["hexbgr"] %> ; Light Yellow
"ColorTable15"=dword:00<%- base["07"]["hexbgr"] %> ; Bright White
