/*
 *  Name:       Base16 <%- scheme %> Dark
 *  Author:     <%- author %>
 *
 *  Ace template by Jan T. Sott (https://github.com/idleberg/)
 */

.ace-<%- schemeSlug > .ace_gutter {
  background: #<%- base["00"]["hex"] %>;
  color: rgb(113,116,116)
}

.ace-<%- schemeSlug > .ace_print-margin {
  width: 1px;
  background: #<%- base["06"]["hex"] %>
}

.ace-<%- schemeSlug > {
  background-color: #<%- base["00"]["hex"] %>;
  color: #<%- base["05"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_cursor {
  color: #<%- base["05"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_marker-layer .ace_selection {
  background: #<%- base["02"]["hex"] %>
}

.ace-<%- schemeSlug >.ace_multiselect .ace_selection.ace_start {
  box-shadow: 0 0 3px 0px #<%- base["00"]["hex"] %>;
  border-radius: 2px
}

.ace-<%- schemeSlug > .ace_marker-layer .ace_step {
  background: rgb(198, 219, 174)
}

.ace-<%- schemeSlug > .ace_marker-layer .ace_bracket {
  margin: -1px 0 0 -1px;
  border: 1px solid #<%- base["03"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_marker-layer .ace_active-line {
  background: rgba(<%- base["02"]["rgb"] %>, 0.33)
}

.ace-<%- schemeSlug > .ace_gutter-active-line {
  background-color: rgba(<%- base["02"]["rgb"] %>, 0.33)
}

.ace-<%- schemeSlug > .ace_marker-layer .ace_selected-word {
  border: 1px solid #<%- base["02"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_fold {
  background-color: #<%- base["0D"]["hex"] %>;
  border-color: #<%- base["05"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_keyword {
  color: #<%- base["0E"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_keyword.ace_operator {
  color: #<%- base["05"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_keyword.ace_other.ace_unit {
  color: #<%- base["09"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_constant {
  color: #<%- base["09"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_constant.ace_numeric {
  color: #<%- base["09"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_constant.ace_character.ace_escape {
  color: #<%- base["0C"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_support.ace_function {
  color: #<%- base["0C"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_support.ace_class {
  color: #<%- base["0A"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_storage {
  color: #<%- base["0E"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_invalid.ace_illegal {
  color: #<%- base["07"]["hex"] %>;
  background-color: #<%- base["08"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_invalid.ace_deprecated {
  color: #<%- base["07"]["hex"] %>;
  background-color: #<%- base["0F"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_string {
  color: #<%- base["0B"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_string.ace_regexp {
  color: #<%- base["0C"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_comment {
  color: #<%- base["03"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_variable {
  color: #<%- base["08"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_meta.ace_selector {
  color: #<%- base["0E"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_entity.ace_other.ace_attribute-name {
  color: #<%- base["09"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_entity.ace_name.ace_function {
  color: #<%- base["0D"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_entity.ace_name.ace_tag {
  color: #<%- base["08"]["hex"] %>
}

.ace-<%- schemeSlug > .ace_markup.ace_list {
  color: #<%- base["08"]["hex"] %>
}