# ~/.i3/config
# i3 config template
# Base16 <%- scheme %> by <%- author %>
# template by Matt Parnell, @parnmatt

set $base00 #<%- base["00"]["hex"] %>
set $base01 #<%- base["01"]["hex"] %>
set $base02 #<%- base["02"]["hex"] %>
set $base03 #<%- base["03"]["hex"] %>
set $base04 #<%- base["04"]["hex"] %>
set $base05 #<%- base["05"]["hex"] %>
set $base06 #<%- base["06"]["hex"] %>
set $base07 #<%- base["07"]["hex"] %>
set $base08 #<%- base["08"]["hex"] %>
set $base09 #<%- base["09"]["hex"] %>
set $base0A #<%- base["0A"]["hex"] %>
set $base0B #<%- base["0B"]["hex"] %>
set $base0C #<%- base["0C"]["hex"] %>
set $base0D #<%- base["0D"]["hex"] %>
set $base0E #<%- base["0E"]["hex"] %>
set $base0F #<%- base["0F"]["hex"] %>

# Window Colours            border  background  text    indicator
client.focused              $base0D $base0D     $base00 $base01
client.focused_inactive     $base02 $base02     $base03 $base01
client.unfocused            $base01 $base01     $base03 $base01
client.urgent               $base02 $base08     $base07 $base08

## remember to add the rest of your configuration

bar {
    ## remember to add your favourite status bar, i.e.,
    # status_command i3status

        colors {
        separator   $base03
        background  $base01
        statusline  $base05

        #                   border  background  text
        focused_workspace   $base0C $base0D     $base00
        active_workspace    $base02 $base02     $base07
        inactive_workspace  $base01 $base01     $base03
        urgent_workspace    $base08 $base08     $base07
    }
}
