<!--
  iTerm2 template
  Chris Kempson (http://chriskempson.com)
-->
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>Ansi 0 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["00"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["00"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["00"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 1 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["08"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["08"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["08"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 10 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["0B"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["0B"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["0B"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 11 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["0A"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["0A"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["0A"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 12 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["0D"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["0D"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["0D"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 13 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["0E"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["0E"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["0E"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 14 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["0C"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["0C"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["0C"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 15 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["07"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["07"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["07"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 2 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["0B"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["0B"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["0B"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 3 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["0A"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["0A"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["0A"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 4 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["0D"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["0D"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["0D"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 5 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["0E"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["0E"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["0E"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 6 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["0C"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["0C"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["0C"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 7 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["05"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["05"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["05"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 8 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["03"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["03"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["03"]["srgb"][0] %></real>
	</dict>
	<key>Ansi 9 Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["08"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["08"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["08"]["srgb"][0] %></real>
	</dict>
	<key>Background Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["07"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["07"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["07"]["srgb"][0] %></real>
	</dict>
	<key>Bold Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["02"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["02"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["02"]["srgb"][0] %></real>
	</dict>
	<key>Cursor Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["02"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["02"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["02"]["srgb"][0] %></real>
	</dict>
	<key>Cursor Text Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["07"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["07"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["07"]["srgb"][0] %></real>
	</dict>
	<key>Foreground Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["02"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["02"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["02"]["srgb"][0] %></real>
	</dict>
	<key>Selected Text Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["02"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["02"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["02"]["srgb"][0] %></real>
	</dict>
	<key>Selection Color</key>
	<dict>
		<key>Color Space</key>
		<string>sRGB</string>
		<key>Blue Component</key>
		<real><%- base["05"]["srgb"][2] %></real>
		<key>Green Component</key>
		<real><%- base["05"]["srgb"][1] %></real>
		<key>Red Component</key>
		<real><%- base["05"]["srgb"][0] %></real>
	</dict>
</dict>
</plist>
