# vim: filetype=yaml
# dunst template
# Base16 <%- scheme %> Dark, by <%- author %>

[urgency_low]
    background = "#<%- base["00"]["hex"] %>"
    foreground = "#<%- base["07"]["hex"] %>"

[urgency_normal]
    background = "#<%- base["00"]["hex"] %>"
    foreground = "#<%- base["0D"]["hex"] %>"

[urgency_critical]
    background = "#<%- base["00"]["hex"] %>"
    foreground = "#<%- base["08"]["hex"] %>"
