# ~/.i3status.conf
# Base16 <%- scheme %>, by <%- author %>
# template by Matt Parnell, @parnmatt

general {
    colors = true
    color_good = "#<%- base["0B"]["hex"] %>"
    color_bad = "#<%- base["08"]["hex"] %>"
    color_degraded = "#<%- base["0A"]["hex"] %>"
    ## remember to add your preferred interval
    # interval = 5
}

## remember to add the rest of your configure
