<?xml version="1.0" encoding="UTF-8"?>
<scheme name="Base16-<%- scheme %>-Light" version="124" parent_scheme="Default">
  <option name="LINE_SPACING" value="1.0" />
  <option name="EDITOR_FONT_SIZE" value="12" />
  <option name="CONSOLE_FONT_NAME" value="Menlo" />
  <option name="CONSOLE_FONT_SIZE" value="12" />
  <option name="CONSOLE_LINE_SPACING" value="1.0" />
  <option name="EDITOR_FONT_NAME" value="Menlo" />
  <colors>
    <option name="ADDED_LINES_COLOR" value="<%- base["0B"]["hex"] %>" />
    <option name="ANNOTATIONS_COLOR" value="<%- base["02"]["hex"] %>" />
    <option name="CARET_COLOR" value="<%- base["01"]["hex"] %>" />
    <option name="CARET_ROW_COLOR" value="<%- base["06"]["hex"] %>" />
    <option name="CONSOLE_BACKGROUND_KEY" value="<%- base["07"]["hex"] %>" />
    <option name="FILESTATUS_ADDED" value="<%- base["01"]["hex"] %>" />
    <option name="FILESTATUS_IDEA_FILESTATUS_IGNORED" value="<%- base["01"]["hex"] %>" />
    <option name="FILESTATUS_MODIFIED" value="<%- base["01"]["hex"] %>" />
    <option name="FILESTATUS_UNKNOWN" value="<%- base["01"]["hex"] %>" />
    <option name="GUTTER_BACKGROUND" value="<%- base["06"]["hex"] %>" />
    <option name="INDENT_GUIDE" value="<%- base["04"]["hex"] %>" />
    <option name="LINE_NUMBERS_COLOR" value="<%- base["00"]["hex"] %>" />
    <option name="METHOD_SEPARATORS_COLOR" value="<%- base["05"]["hex"] %>" />
    <option name="MODIFIED_LINES_COLOR" value="<%- base["0B"]["hex"] %>" />
    <option name="NOTIFICATION_BACKGROUND" value="<%- base["01"]["hex"] %>" />
    <option name="READONLY_FRAGMENT_BACKGROUND" value="<%- base["00"]["hex"] %>" />
    <option name="RECURSIVE_CALL_ATTRIBUTES" value="<%- base["05"]["hex"] %>" />
    <option name="RIGHT_MARGIN_COLOR" value="<%- base["01"]["hex"] %>" />
    <option name="SELECTED_TEARLINE_COLOR" value="<%- base["02"]["hex"] %>" />
    <option name="SELECTION_BACKGROUND" value="<%- base["03"]["hex"] %>" />
    <option name="SELECTION_FOREGROUND" value="<%- base["07"]["hex"] %>" />
    <option name="TEARLINE_COLOR" value="<%- base["02"]["hex"] %>" />
    <option name="WHITESPACES" value="<%- base["05"]["hex"] %>" />
  </colors>
  <attributes>
    <option name="TEXT">
      <value>
        <option name="FOREGROUND" value="<%- base["00"]["hex"] %>" />
        <option name="BACKGROUND" value="<%- base["07"]["hex"] %>" />
      </value>
    </option>    
    <option name="TEXT_SEARCH_RESULT_ATTRIBUTES">
      <value>
        <option name="ERROR_STRIPE_COLOR" value="<%- base["06"]["hex"] %>" />
      </value>
    </option>
    <option name="DEFAULT_TEMPLATE_LANGUAGE_COLOR">
      <value>
        <option name="FOREGROUND" value="<%- base["00"]["hex"] %>" />
        <option name="BACKGROUND" value="<%- base["07"]["hex"] %>" />
      </value>
    </option>
    <option name="DEFAULT_IDENTIFIER">
        <value>
            <option name="FOREGROUND" value="<%- base["08"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_NUMBER">
        <value>
            <option name="FOREGROUND" value="<%- base["09"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_KEYWORD">
        <value>
            <option name="FOREGROUND" value="<%- base["0E"]["hex"] %>" />
            <option name="FONT_TYPE" value="1" />
        </value>
    </option>
    <option name="DEFAULT_STRING">
        <value>
            <option name="FOREGROUND" value="<%- base["0B"]["hex"] %>" />
            <option name="FONT_TYPE" value="1" />
        </value>
    </option>
    <option name="DEFAULT_BLOCK_COMMENT">
        <value>
            <option name="FOREGROUND" value="<%- base["03"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_LINE_COMMENT">
        <value>
            <option name="FOREGROUND" value="<%- base["03"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_DOC_COMMENT">
        <value>
            <option name="FOREGROUND" value="<%- base["03"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_OPERATION_SIGN">
        <value>
            <option name="FOREGROUND" value="<%- base["02"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_BRACES">
        <value>
            <option name="FOREGROUND" value="<%- base["01"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_DOT">
        <value>
            <option name="FOREGROUND" value="<%- base["01"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_SEMICOLON">
        <value>
            <option name="FOREGROUND" value="<%- base["01"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_COMMA">
        <value>
            <option name="FOREGROUND" value="<%- base["01"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_PARENTHS">
        <value>
            <option name="FOREGROUND" value="<%- base["01"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_BRACKETS">
        <value>
            <option name="FOREGROUND" value="<%- base["01"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_LABEL">
        <value>
            <option name="FOREGROUND" value="<%- base["01"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_CONSTANT">
        <value>
            <option name="FOREGROUND" value="<%- base["09"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_LOCAL_VARIABLE">
        <value>
            <option name="FOREGROUND" value="<%- base["08"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_GLOBAL_VARIABLE">
        <value>
            <option name="FOREGROUND" value="<%- base["08"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_FUNCTION_DECLARATION">
        <value>
            <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
            <option name="FONT_TYPE" value="1" />
        </value>
    </option>
    <option name="DEFAULT_FUNCTION_CALL">
        <value>
            <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_PARAMETER">
        <value>
            <option name="FOREGROUND" value="<%- base["01"]["hex"] %>" />
        </value>
    </option>
    <option name="PY.SELF_PARAMETER">
      <value>
        <option name="FOREGROUND" value="<%- base["0E"]["hex"] %>" />
      </value>
    </option>
    <option name="DEFAULT_CLASS_NAME">
        <value>
            <option name="FOREGROUND" value="<%- base["0F"]["hex"] %>" />
            <option name="FONT_TYPE" value="1" />
        </value>
    </option>
    <option name="DEFAULT_INTERFACE_NAME">
        <value>
            <option name="FOREGROUND" value="<%- base["0A"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_CLASS_REFERENCE">
        <value>
            <option name="FOREGROUND" value="<%- base["0F"]["hex"] %>" />
            <option name="FONT_TYPE" value="1" />
        </value>
    </option>
    <option name="DEFAULT_INSTANCE_METHOD">
        <value>
            <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
            <option name="FONT_TYPE" value="1" />
        </value>
    </option>
    <option name="DEFAULT_INSTANCE_FIELD">
        <value>
            <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_STATIC_METHOD">
        <value>
            <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
            <option name="FONT_TYPE" value="1" />
        </value>
    </option>
    <option name="DEFAULT_STATIC_FIELD">
        <value>
            <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_DOC_MARKUP">
        <value>
            <option name="FOREGROUND" value="<%- base["02"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_DOC_COMMENT_TAG">
        <value>
            <option name="FOREGROUND" value="<%- base["03"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_DOC_COMMENT_TAG_VALUE">
        <value>
            <option name="FOREGROUND" value="<%- base["03"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_VALID_STRING_ESCAPE">
        <value>
            <option name="FOREGROUND" value="<%- base["08"]["hex"] %>" />
            <option name="FONT_TYPE" value="1" />
        </value>
    </option>
    <option name="DEFAULT_INVALID_STRING_ESCAPE">
        <value>
            <option name="FOREGROUND" value="<%- base["0F"]["hex"] %>" />
            <option name="FONT_TYPE" value="1" />
        </value>
    </option>
    <option name="DEFAULT_PREDEFINED_SYMBOL">
        <value>
            <option name="FOREGROUND" value="<%- base["01"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_METADATA">
        <value>
            <option name="FOREGROUND" value="<%- base["01"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_TAG">
        <value>
            <option name="FOREGROUND" value="<%- base["08"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_ATTRIBUTE">
        <value>
            <option name="FOREGROUND" value="<%- base["08"]["hex"] %>" />
        </value>
    </option>
    <option name="DEFAULT_ENTITY">
        <value>
            <option name="FOREGROUND" value="<%- base["0F"]["hex"] %>" />
        </value>
    </option> 
    <option name="ABSTRACT_CLASS_NAME_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0F"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="ABSTRACT_METHOD_ATTRIBUTES">
      <value />
    </option>
    <option name="ANNOTATION_ATTRIBUTE_NAME_ATTRIBUTES">
      <value />
    </option>
    <option name="ANNOTATION_NAME_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
        <option name="EFFECT_TYPE" value="1" />
      </value>
    </option>
    <option name="ANONYMOUS_CLASS_NAME_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0F"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="BAD_CHARACTER">
      <value>
        <option name="FOREGROUND" value="<%- base["08"]["hex"] %>" />
      </value>
    </option>
    <option name="BREAKPOINT_ATTRIBUTES">
      <value>
        <option name="BACKGROUND" value="<%- base["0F"]["hex"] %>" />
      </value>
    </option>
    <option name="CLASS_NAME_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0F"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="CONSOLE_BLACK_OUTPUT">
      <value>
        <option name="FOREGROUND" value="0" />
      </value>
    </option>
    <option name="CONSOLE_BLUE_BRIGHT_OUTPUT">
      <value>
        <option name="FOREGROUND" value="5c5cff" />
      </value>
    </option>
    <option name="CONSOLE_BLUE_OUTPUT">
      <value>
        <option name="FOREGROUND" value="ee" />
      </value>
    </option>
    <option name="CONSOLE_CYAN_BRIGHT_OUTPUT">
      <value>
        <option name="FOREGROUND" value="ffff" />
      </value>
    </option>
    <option name="CONSOLE_CYAN_OUTPUT">
      <value>
        <option name="FOREGROUND" value="cccc" />
      </value>
    </option>
    <option name="CONSOLE_DARKGRAY_OUTPUT">
      <value>
        <option name="FOREGROUND" value="555555" />
      </value>
    </option>
    <option name="CONSOLE_ERROR_OUTPUT">
      <value>
        <option name="FOREGROUND" value="<%- base["08"]["hex"] %>" />
      </value>
    </option>
    <option name="CONSOLE_GRAY_OUTPUT">
      <value>
        <option name="FOREGROUND" value="aaaaaa" />
      </value>
    </option>
    <option name="CONSOLE_GREEN_BRIGHT_OUTPUT">
      <value>
        <option name="FOREGROUND" value="ff00" />
      </value>
    </option>
    <option name="CONSOLE_GREEN_OUTPUT">
      <value>
        <option name="FOREGROUND" value="cd00" />
      </value>
    </option>
    <option name="CONSOLE_MAGENTA_BRIGHT_OUTPUT">
      <value>
        <option name="FOREGROUND" value="ff00ff" />
      </value>
    </option>
    <option name="CONSOLE_MAGENTA_OUTPUT">
      <value>
        <option name="FOREGROUND" value="cd00cd" />
      </value>
    </option>
    <option name="CONSOLE_NORMAL_OUTPUT">
      <value>
        <option name="FOREGROUND" value="<%- base["03"]["hex"] %>" />
      </value>
    </option>
    <option name="CONSOLE_RED_BRIGHT_OUTPUT">
      <value>
        <option name="FOREGROUND" value="ff0000" />
      </value>
    </option>
    <option name="CONSOLE_RED_OUTPUT">
      <value>
        <option name="FOREGROUND" value="cd0000" />
      </value>
    </option>
    <option name="CONSOLE_SYSTEM_OUTPUT">
      <value>
        <option name="FOREGROUND" value="<%- base["00"]["hex"] %>" />
      </value>
    </option>
    <option name="CONSOLE_USER_INPUT">
      <value>
        <option name="FOREGROUND" value="<%- base["00"]["hex"] %>" />
        <option name="FONT_TYPE" value="2" />
      </value>
    </option>
    <option name="CONSOLE_WHITE_OUTPUT">
      <value>
        <option name="FOREGROUND" value="ffffff" />
      </value>
    </option>
    <option name="CONSOLE_YELLOW_BRIGHT_OUTPUT">
      <value>
        <option name="FOREGROUND" value="eaea00" />
      </value>
    </option>
    <option name="CONSOLE_YELLOW_OUTPUT">
      <value>
        <option name="FOREGROUND" value="cdcd00" />
      </value>
    </option>
    <option name="CONSTRUCTOR_CALL_ATTRIBUTES">
      <value />
    </option>
    <option name="CONSTRUCTOR_DECLARATION_ATTRIBUTES">
      <value />
    </option>
    <option name="CTRL_CLICKABLE">
      <value>
        <option name="EFFECT_COLOR" value="<%- base["01"]["hex"] %>" />
        <option name="EFFECT_TYPE" value="1" />
      </value>
    </option>
    <option name="CUSTOM_INVALID_STRING_ESCAPE_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["08"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="CUSTOM_KEYWORD1_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0E"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="CUSTOM_KEYWORD2_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="660e7a" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="CUSTOM_KEYWORD3_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="6666" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="CUSTOM_KEYWORD4_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="660000" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="CUSTOM_LINE_COMMENT_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="808080" />
        <option name="FONT_TYPE" value="2" />
      </value>
    </option>
    <option name="CUSTOM_MULTI_LINE_COMMENT_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="808080" />
        <option name="FONT_TYPE" value="2" />
      </value>
    </option>
    <option name="CUSTOM_NUMBER_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0C"]["hex"] %>" />
      </value>
    </option>
    <option name="CUSTOM_STRING_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="8000" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="CUSTOM_VALID_STRING_ESCAPE_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["08"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="DELETED_TEXT_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["03"]["hex"] %>" />
        <option name="BACKGROUND" value="<%- base["01"]["hex"] %>" />
        <option name="EFFECT_TYPE" value="1" />
      </value>
    </option>
    <option name="DEPRECATED_ATTRIBUTES">
      <value>
        <option name="EFFECT_COLOR" value="<%- base["08"]["hex"] %>" />
        <option name="EFFECT_TYPE" value="3" />
      </value>
    </option>
    <option name="DIFF_CONFLICT">
      <value>
        <option name="BACKGROUND" value="<%- base["08"]["hex"] %>" />
        <option name="ERROR_STRIPE_COLOR" value="ffc8bd" />
      </value>
    </option>
    <option name="DIFF_DELETED">
      <value>
        <option name="BACKGROUND" value="<%- base["0E"]["hex"] %>" />
        <option name="ERROR_STRIPE_COLOR" value="cbcbcb" />
      </value>
    </option>
    <option name="DIFF_INSERTED">
      <value>
        <option name="BACKGROUND" value="<%- base["0B"]["hex"] %>" />
        <option name="ERROR_STRIPE_COLOR" value="baeeba" />
      </value>
    </option>
    <option name="DIFF_MODIFIED">
      <value>
        <option name="BACKGROUND" value="<%- base["0C"]["hex"] %>" />
        <option name="ERROR_STRIPE_COLOR" value="bccff9" />
      </value>
    </option>
    <option name="DOC_COMMENT_TAG_VALUE">
      <value>
        <option name="FOREGROUND" value="<%- base["05"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="DUPLICATE_FROM_SERVER">
      <value />
    </option>
    <option name="ENUM_NAME_ATTRIBUTES">
      <value />
    </option>
    <option name="ERRORS_ATTRIBUTES">
      <value>
        <option name="EFFECT_COLOR" value="<%- base["08"]["hex"] %>" />
        <option name="EFFECT_TYPE" value="2" />
        <option name="ERROR_STRIPE_COLOR" value="<%- base["08"]["hex"] %>" />
      </value>
    </option>
    <option name="EXECUTIONPOINT_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="ffffff" />
        <option name="BACKGROUND" value="ff" />
      </value>
    </option>
    <option name="FOLDED_TEXT_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["01"]["hex"] %>" />
        <option name="BACKGROUND" value="<%- base["04"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
        <option name="EFFECT_TYPE" value="1" />
      </value>
    </option>
    <option name="FOLLOWED_HYPERLINK_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0E"]["hex"] %>" />
        <option name="BACKGROUND" value="<%- base["06"]["hex"] %>" />
        <option name="EFFECT_COLOR" value="<%- base["0E"]["hex"] %>" />
        <option name="EFFECT_TYPE" value="1" />
      </value>
    </option>
    <option name="GENERIC_SERVER_ERROR_OR_WARNING">
      <value>
        <option name="EFFECT_COLOR" value="<%- base["09"]["hex"] %>" />
        <option name="EFFECT_TYPE" value="2" />
        <option name="ERROR_STRIPE_COLOR" value="<%- base["09"]["hex"] %>" />
      </value>
    </option>
    <option name="GHERKIN_COMMENT">
      <value>
        <option name="FOREGROUND" value="<%- base["04"]["hex"] %>" />
      </value>
    </option>
    <option name="GHERKIN_OUTLINE_PARAMETER_SUBSTITUTION">
      <value>
        <option name="FOREGROUND" value="<%- base["05"]["hex"] %>" />
      </value>
    </option>
    <option name="GHERKIN_PYSTRING">
      <value>
        <option name="FOREGROUND" value="<%- base["05"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="GHERKIN_TABLE_HEADER_CELL">
      <value>
        <option name="FOREGROUND" value="<%- base["03"]["hex"] %>" />
      </value>
    </option>
    <option name="GROOVY_KEYWORD">
      <value>
        <option name="FOREGROUND" value="<%- base["0E"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="HYPERLINK_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
        <option name="EFFECT_COLOR" value="<%- base["0D"]["hex"] %>" />
        <option name="EFFECT_TYPE" value="1" />
      </value>
    </option>
    <option name="IDENTIFIER_UNDER_CARET_ATTRIBUTES">
      <value>
        <option name="FONT_TYPE" value="1" />
        <option name="EFFECT_COLOR" value="<%- base["04"]["hex"] %>" />
        <option name="ERROR_STRIPE_COLOR" value="<%- base["04"]["hex"] %>" />
      </value>
    </option>
    <option name="IMPLICIT_ANONYMOUS_CLASS_PARAMETER_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0E"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="INFO_ATTRIBUTES">
      <value>
        <option name="EFFECT_COLOR" value="cccccc" />
        <option name="EFFECT_TYPE" value="2" />
        <option name="ERROR_STRIPE_COLOR" value="ffffcc" />
      </value>
    </option>
    <option name="INHERITED_METHOD_ATTRIBUTES">
      <value />
    </option>
    <option name="INJECTED_LANGUAGE_FRAGMENT">
      <value>
        <option name="FOREGROUND" value="<%- base["0C"]["hex"] %>" />
      </value>
    </option>
    <option name="INSTANCE_FIELD_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="INTERFACE_NAME_ATTRIBUTES">
      <value />
    </option>
    <option name="Instance property reference ID">
      <value>
        <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
      </value>
    </option>
    <option name="LINE_FULL_COVERAGE">
      <value>
        <option name="FOREGROUND" value="ccffcc" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="LINE_NONE_COVERAGE">
      <value>
        <option name="FOREGROUND" value="ffcccc" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="LINE_PARTIAL_COVERAGE">
      <value>
        <option name="FOREGROUND" value="ffffcc" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="LIVE_TEMPLATE_ATTRIBUTES">
      <value>
        <option name="EFFECT_COLOR" value="ff0000" />
      </value>
    </option>
    <option name="LOCAL_VARIABLE_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["08"]["hex"] %>" />
      </value>
    </option>
    <option name="LOG_ERROR_OUTPUT">
      <value>
        <option name="FOREGROUND" value="<%- base["08"]["hex"] %>" />
      </value>
    </option>
    <option name="LOG_EXPIRED_ENTRY">
      <value>
        <option name="FOREGROUND" value="<%- base["0F"]["hex"] %>" />
      </value>
    </option>
    <option name="LOG_WARNING_OUTPUT">
      <value>
        <option name="FOREGROUND" value="<%- base["09"]["hex"] %>" />
      </value>
    </option>
    <option name="List/map to object conversion">
      <value>
        <option name="FOREGROUND" value="<%- base["05"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="MATCHED_BRACE_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["00"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="METHOD_CALL_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
      </value>
    </option>
    <option name="METHOD_DECLARATION_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="Map key">
      <value>
        <option name="FOREGROUND" value="<%- base["0B"]["hex"] %>" />
      </value>
    </option>
    <option name="NOT_USED_ELEMENT_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["03"]["hex"] %>" />
      </value>
    </option>
    <option name="PARAMETER_ATTRIBUTES">
      <value />
    </option>
    <option name="REASSIGNED_LOCAL_VARIABLE_ATTRIBUTES">
      <value />
    </option>
    <option name="REASSIGNED_PARAMETER_ATTRIBUTES">
      <value />
    </option>
    <option name="SASS_MIXIN">
      <value>
        <option name="FOREGROUND" value="<%- base["0F"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="SASS_VARIABLE">
      <value>
        <option name="FOREGROUND" value="<%- base["0F"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="SCOPE_KEY_All">
      <value />
    </option>
    <option name="SCOPE_KEY_Non-Project Files">
      <value />
    </option>
    <option name="SCOPE_KEY_Problems">
      <value />
    </option>
    <option name="SCOPE_KEY_Production">
      <value />
    </option>
    <option name="SCOPE_KEY_Project Files">
      <value />
    </option>
    <option name="SCOPE_KEY_Tests">
      <value />
    </option>
    <option name="SEARCH_RESULT_ATTRIBUTES">
      <value>
        <option name="BACKGROUND" value="<%- base["06"]["hex"] %>" />
      </value>
    </option>
    <option name="STATIC_FIELD_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
      </value>
    </option>
    <option name="STATIC_FINAL_FIELD_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0D"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="STATIC_METHOD_ATTRIBUTES">
      <value />
    </option>
    <option name="Static property reference ID">
      <value>
        <option name="FOREGROUND" value="660e7a" />
        <option name="FONT_TYPE" value="2" />
      </value>
    </option>
    <option name="TEMPLATE_VARIABLE_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="7f0000" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="TODO_DEFAULT_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0E"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
        <option name="ERROR_STRIPE_COLOR" value="<%- base["0E"]["hex"] %>" />
      </value>
    </option>
    <option name="TYPE_PARAMETER_NAME_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="20999d" />
      </value>
    </option>
    <option name="TYPO">
      <value>
        <option name="EFFECT_COLOR" value="8000" />
        <option name="EFFECT_TYPE" value="2" />
      </value>
    </option>
    <option name="UNMATCHED_BRACE_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["08"]["hex"] %>" />
        <option name="FONT_TYPE" value="1" />
      </value>
    </option>
    <option name="Unresolved reference access">
      <value>
        <option name="FOREGROUND" value="<%- base["05"]["hex"] %>" />
        <option name="EFFECT_COLOR" value="<%- base["08"]["hex"] %>" />
        <option name="EFFECT_TYPE" value="1" />
      </value>
    </option>
    <option name="WARNING_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="<%- base["0F"]["hex"] %>" />
        <option name="EFFECT_TYPE" value="1" />
        <option name="ERROR_STRIPE_COLOR" value="ffff00" />
      </value>
    </option>
    <option name="WRITE_IDENTIFIER_UNDER_CARET_ATTRIBUTES">
      <value>
        <option name="FONT_TYPE" value="1" />
        <option name="EFFECT_COLOR" value="<%- base["02"]["hex"] %>" />
        <option name="ERROR_STRIPE_COLOR" value="<%- base["02"]["hex"] %>" />
      </value>
    </option>
    <option name="WRITE_SEARCH_RESULT_ATTRIBUTES">
      <value>
        <option name="BACKGROUND" value="<%- base["06"]["hex"] %>" />
      </value>
    </option>
    <option name="WRONG_REFERENCES_ATTRIBUTES">
      <value>
        <option name="FOREGROUND" value="ff0000" />
      </value>
    </option>
    <option name="Scala Template lazy val/var">
      <value>
        <option name="FOREGROUND" value="<%- base["09"]["hex"] %>" />
      </value>
    </option>
    <option name="Scala Template val">
      <value>
        <option name="FOREGROUND" value="<%- base["09"]["hex"] %>" />
      </value>
    </option>
    <option name="Scala Template var">
      <value>
        <option name="FOREGROUND" value="<%- base["09"]["hex"] %>" />
      </value>
    </option>
  </attributes>
</scheme>
