/**
 * Base16 <%- scheme %> Light
 *
 * @author <%- author %>
 *
 * Rainbow template by Jan T. Sott (https://github.com/idleberg/)
 * Original Base16 color scheme by Chris Kempson (https://github.com/chriskempson/base16)
 */
@base00: #<%- base["00"]["hex"] %>;
@base01: #<%- base["01"]["hex"] %>;
@base02: #<%- base["02"]["hex"] %>;
@base03: #<%- base["03"]["hex"] %>;
@base04: #<%- base["04"]["hex"] %>;
@base05: #<%- base["05"]["hex"] %>;
@base06: #<%- base["06"]["hex"] %>;
@base07: #<%- base["07"]["hex"] %>;
@base08: #<%- base["08"]["hex"] %>;
@base09: #<%- base["09"]["hex"] %>;
@base0a: #<%- base["0A"]["hex"] %>;
@base0b: #<%- base["0B"]["hex"] %>;
@base0c: #<%- base["0C"]["hex"] %>;
@base0d: #<%- base["0D"]["hex"] %>;
@base0e: #<%- base["0E"]["hex"] %>;
@base0f: #<%- base["0F"]["hex"] %>;

pre {
    background-color: @base07;
    word-wrap: break-word;
    margin: 0px;
    padding: 10px;
    color: @base00;
    font-size: 14px;
    margin-bottom: 20px;
}

pre, code {
    font-family: 'Monaco', courier, monospace;
}

pre .comment {
    color: @base04;
}

pre .variable.global, pre .variable.class, pre .variable.instance {
    color: @base08; // red
}

pre .constant.numeric, pre .constant.language, pre .constant.hex-color, pre .keyword.unit {
    color: @base09; // orange
}

pre .constant, pre .entity, pre .entity.class, pre .support {
    color: @base0a; // yellow
}

pre .constant.symbol, pre .string {
    color: @base0b; // green
}

pre .entity.function, pre .support.css-property, pre .selector {
    color: @base0d; // blue
}

pre .keyword, pre .storage {
    color: @base0e; // purple
}
