<ResourceDictionary  xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation" xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml">     <ResourceDictionary.MergedDictionaries>         <ResourceDictionary Source="Base.xaml"></ResourceDictionary>     </ResourceDictionary.MergedDictionaries>     <Style x:Key="QueryBoxStyle" BasedOn="{StaticResource BaseQueryBoxStyle}" TargetType="{x:Type TextBox}">         <Setter Property="Background" Value="#<%- base["01"]["hex"] %>"/>         <Setter Property="Foreground" Value="#<%- base["0A"]["hex"] %>" />     </Style>     <Style x:Key="WindowBorderStyle" BasedOn="{StaticResource BaseWindowBorderStyle}" TargetType="{x:Type Border}">         <Setter Property="Background" Value="#<%- base["00"]["hex"] %>"></Setter>     </Style>     <Style x:Key="WindowStyle" TargetType="{x:Type Window}" BasedOn="{StaticResource BaseWindowStyle}" >     </Style>     <Style x:Key="PendingLineStyle" BasedOn="{StaticResource BasePendingLineStyle}" TargetType="{x:Type Line}" >     </Style>     <Style x:Key="ItemTitleStyle" BasedOn="{StaticResource BaseItemTitleStyle}" TargetType="{x:Type TextBlock}" >         <Setter Property="Foreground" Value="#<%- base["05"]["hex"] %>"></Setter>     </Style>     <Style x:Key="ItemSubTitleStyle" BasedOn="{StaticResource BaseItemSubTitleStyle}" TargetType="{x:Type TextBlock}" >         <Setter Property="Foreground"  Value="#<%- base["06"]["hex"] %>"></Setter>     </Style>     <Style x:Key="ItemTitleSelectedStyle" BasedOn="{StaticResource BaseItemTitleSelectedStyle}" TargetType="{x:Type TextBlock}">         <Setter Property="Foreground" Value="#<%- base["0A"]["hex"] %>" />     </Style>     <Style x:Key="ItemSubTitleSelectedStyle" BasedOn="{StaticResource BaseItemSubTitleSelectedStyle}" TargetType="{x:Type TextBlock}">         <Setter Property="Foreground" Value="#<%- base["06"]["hex"] %>" />     </Style>     <Color x:Key="ItemSelectedBackgroundColor">#<%- base["01"]["hex"] %></Color>     <Style x:Key="ThumbStyle" BasedOn="{StaticResource BaseThumbStyle}" TargetType="{x:Type Thumb}">     </Style>     <Style x:Key="ScrollBarStyle" BasedOn="{StaticResource BaseScrollBarStyle}" TargetType="{x:Type ScrollBar}">     </Style> </ResourceDictionary>