editor
foreground: <%- base["01"]["hex"] %>
background: <%- base["07"]["hex"] %>
caret: <%- base["0E"]["hex"] %>

editor-selection
foreground: <%- base["07"]["hex"] %>
background: <%- base["02"]["hex"] %>

H1
foreground: <%- base["0C"]["hex"] %>
font-style: bold

H2
foreground: <%- base["0C"]["hex"] %>
font-style: bold

H3
foreground: <%- base["0C"]["hex"] %>
font-style: bold

H4
foreground: <%- base["0C"]["hex"] %>
font-style: bold

H5
foreground: <%- base["0C"]["hex"] %>
font-style: bold

H6
foreground: <%- base["0C"]["hex"] %>
font-style: bold

EMPH
foreground: <%- base["0A"]["hex"] %>
font-style: italic

STRONG
foreground: <%- base["09"]["hex"] %>
font-style: bold

HRULE
foreground: <%- base["03"]["hex"] %>

LIST_BULLET
foreground: <%- base["0D"]["hex"] %>

LIST_ENUMERATOR
foreground: <%- base["0D"]["hex"] %>

LINK
foreground: <%- base["0B"]["hex"] %>

AUTO_LINK_URL
foreground: <%- base["0B"]["hex"] %>

AUTO_LINK_EMAIL
foreground: <%- base["0B"]["hex"] %>

REFERENCE
foreground: <%- base["0C"]["hex"] %>

IMAGE
foreground: <%- base["0E"]["hex"] %>

CODE
foreground: <%- base["03"]["hex"] %>
background: <%- base["06"]["hex"] %>

VERBATIM
foreground: <%- base["03"]["hex"] %>
background: <%- base["06"]["hex"] %>

HTML_ENTITY
foreground: <%- base["0E"]["hex"] %>

COMMENT
foreground: <%- base["04"]["hex"] %>

BLOCKQUOTE
foreground: <%- base["08"]["hex"] %>