<?xml version="1.0" encoding="UTF-8"?>
<!--
  Name:
    Base16 <%- scheme %> Dark

  Credits:
    Original Base16 color schemes by Chris Kempson
    gedit template by Jan T. Sott

  Installation:
    Copy style to the respective directories, replace GTK version if necessary!

    Linux:
      /usr/share/gtksourceview-2.0/styles
    Mac OS X (MacPorts):
      /opt/local/share/gtksourceview-2.0/styles
    Windows:
      %PROGRAMFILES%\gedit\share\gtksourceview-2.0\styles

  Base16 Project:
    https://github.com/chriskempson/base16
-->

<style-scheme id="base16-<%- schemeSlug %>-dark" _name="Base16 <%- scheme %> Dark" version="1.0">

  <!-- Meta -->
  <author><%- author %></author>
  <_description>Base16 <%- scheme %> Dark</_description>

  <!-- Palette -->
  <color name="base00" value="#<%- base["00"]["hex"] %>"/>
  <color name="base01" value="#<%- base["01"]["hex"] %>"/>
  <color name="base02" value="#<%- base["02"]["hex"] %>"/>
  <color name="base03" value="#<%- base["03"]["hex"] %>"/>
  <color name="base04" value="#<%- base["04"]["hex"] %>"/>
  <color name="base05" value="#<%- base["05"]["hex"] %>"/>
  <color name="base06" value="#<%- base["06"]["hex"] %>"/>
  <color name="base07" value="#<%- base["07"]["hex"] %>"/>
  <color name="base08" value="#<%- base["08"]["hex"] %>"/>
  <color name="base09" value="#<%- base["09"]["hex"] %>"/>
  <color name="base0A" value="#<%- base["0A"]["hex"] %>"/>
  <color name="base0B" value="#<%- base["0B"]["hex"] %>"/>
  <color name="base0C" value="#<%- base["0C"]["hex"] %>"/>
  <color name="base0D" value="#<%- base["0D"]["hex"] %>"/>
  <color name="base0E" value="#<%- base["0E"]["hex"] %>"/>
  <color name="base0F" value="#<%- base["0F"]["hex"] %>"/>

  <!-- Styles -->
  <style name="bracket-match" background="base01" bold="true"/>
  <style name="bracket-mismatch" background="base01" underline="true"/>
  <style name="css:at-rules" foreground="base0E"/>
  <style name="css:color" foreground="base05"/>
  <style name="css:keyword" foreground="base0A"/>
  <style name="current-line" background="base01"/>
  <style name="cursor" foreground="base03"/>
  <style name="def:base-n-integer" foreground="base09"/>
  <style name="def:boolean" foreground="base09"/>
  <style name="def:builtin" foreground="base09"/>
  <style name="def:character" foreground="base09"/>
  <style name="def:comment" foreground="base04"/>
  <style name="def:complex" foreground="base09"/>
  <style name="def:decimal" foreground="base09"/>
  <style name="def:doc-comment" foreground="base04"/>
  <style name="def:doc-comment-element" foreground="base04"/>
  <style name="def:error" foreground="base07" background="base08"/>
  <style name="def:floating-point" foreground="base09"/>
  <style name="def:function" foreground="base0D"/>
  <style name="def:identifier" foreground="base08"/>
  <style name="def:keyword" foreground="base0E"/>
  <style name="def:note" foreground="base04"/>
  <style name="def:number" foreground="base09"/>
  <style name="def:operator" foreground="base0C"/>
  <style name="def:preprocessor" foreground="base09"/>
  <style name="def:reserved" foreground="base0E"/>
  <style name="def:shebang" foreground="base04"/>
  <style name="def:special-char" foreground="base09"/>
  <style name="def:special-constant" foreground="base09"/>
  <style name="def:statement" foreground="base0E"/>
  <style name="def:string" foreground="base0B"/>
  <style name="def:type" foreground="base0A"/>
  <style name="draw-spaces" foreground="base02"/>
  <style name="html:dtd" foreground="base0B"/>
  <style name="html:tag" foreground="base08"/>
  <style name="js:function" foreground="base0D"/>
  <style name="line-numbers" foreground="base06" background="base01"/>
  <style name="perl:builtin" foreground="base0D"/>
  <style name="perl:include-statement" foreground="base0E"/>
  <style name="perl:special-variable" foreground="base09"/>
  <style name="perl:variable" foreground="base08"/>
  <style name="php:string" foreground="base0B"/>
  <style name="python:builtin-constant" foreground="base0E"/>
  <style name="python:builtin-function" foreground="base0D"/>
  <style name="python:module-handler" foreground="base0E"/>
  <style name="python:special-variable" foreground="base0E"/>
  <style name="ruby:attribute-definition" foreground="base0E"/>
  <style name="ruby:builtin" foreground="base08"/>
  <style name="ruby:class-variable" foreground="base08"/>
  <style name="ruby:constant" foreground="base08"/>
  <style name="ruby:global-variable" foreground="base0D"/>
  <style name="ruby:instance-variable" foreground="base08"/>
  <style name="ruby:module-handler" foreground="base0E"/>
  <style name="ruby:predefined-variable" foreground="base09"/>
  <style name="ruby:regex" foreground="base08"/>
  <style name="ruby:special-variable" foreground="base0E"/>
  <style name="ruby:symbol" foreground="base0B"/>
  <style name="rubyonrails:attribute-definition" foreground="base0E"/>
  <style name="rubyonrails:block-parameter" foreground="base09"/>
  <style name="rubyonrails:builtin" foreground="base08"/>
  <style name="rubyonrails:class-inherit" foreground="base0B"/>
  <style name="rubyonrails:class-name" foreground="base0A"/>
  <style name="rubyonrails:class-variable" foreground="base08"/>
  <style name="rubyonrails:complex-interpolation" foreground="base09"/>
  <style name="rubyonrails:constant" foreground="base08"/>
  <style name="rubyonrails:global-variable" foreground="base0D"/>
  <style name="rubyonrails:instance-variable" foreground="base08"/>
  <style name="rubyonrails:module-handler" foreground="base0E"/>
  <style name="rubyonrails:module-name" foreground="base0A"/>
  <style name="rubyonrails:predefined-variable" foreground="base09"/>
  <style name="rubyonrails:rails" foreground="base08"/>
  <style name="rubyonrails:regex" foreground="base08"/>
  <style name="rubyonrails:simple-interpolation" foreground="base09"/>
  <style name="rubyonrails:special-variable" foreground="base0E"/>
  <style name="rubyonrails:symbol" foreground="base0B"/>
  <style name="search-match" background="base01" bold="true" underline="true"/>
  <style name="selection" foreground="base06" background="base02"/>
  <style name="text" foreground="base06" background="base00"/>
  <style name="xml:attribute-name" foreground="base08"/>
  <style name="xml:doctype" foreground="base08"/>
  <style name="xml:element-name" foreground="base08"/>
  <style name="xml:namespace" foreground="base08"/>
  <style name="xml:tag" foreground="base08"/>

</style-scheme>
