! Base16 <%- scheme %>
! Scheme: <%- author %>

#define base00 #<%- base["00"]["hex"] %>
#define base01 #<%- base["01"]["hex"] %>
#define base02 #<%- base["02"]["hex"] %>
#define base03 #<%- base["03"]["hex"] %>
#define base04 #<%- base["04"]["hex"] %>
#define base05 #<%- base["05"]["hex"] %>
#define base06 #<%- base["06"]["hex"] %>
#define base07 #<%- base["07"]["hex"] %>
#define base08 #<%- base["08"]["hex"] %>
#define base09 #<%- base["09"]["hex"] %>
#define base0A #<%- base["0A"]["hex"] %>
#define base0B #<%- base["0B"]["hex"] %>
#define base0C #<%- base["0C"]["hex"] %>
#define base0D #<%- base["0D"]["hex"] %>
#define base0E #<%- base["0E"]["hex"] %>
#define base0F #<%- base["0F"]["hex"] %>

*foreground:   base02
*background:   base07
*cursorColor:  base02

*color0:       base00
*color1:       base08
*color2:       base0B
*color3:       base0A
*color4:       base0D
*color5:       base0E
*color6:       base0C
*color7:       base05

*color8:       base03
*color9:       base09
*color10:      base01
*color11:      base02
*color12:      base04
*color13:      base06
*color14:      base0F
*color15:      base07
