#lang info
{#
# DrRacket Template
# Christopher D. Walborn
#}
;; Base16 <%- scheme %> (https://github.com/chriskempson/base16)
;; Scheme: <%- author %>

;; pkg metadata
(define deps '("base"))

;; color scheme
(define base00 #(<%- base["00"]["rgb"][0] %> <%- base["00"]["rgb"][1] %> <%- base["00"]["rgb"][2] %>))
(define base01 #(<%- base["01"]["rgb"][0] %> <%- base["01"]["rgb"][1] %> <%- base["01"]["rgb"][2] %>))
(define base02 #(<%- base["02"]["rgb"][0] %> <%- base["02"]["rgb"][1] %> <%- base["02"]["rgb"][2] %>))
(define base03 #(<%- base["03"]["rgb"][0] %> <%- base["03"]["rgb"][1] %> <%- base["03"]["rgb"][2] %>))
(define base04 #(<%- base["04"]["rgb"][0] %> <%- base["04"]["rgb"][1] %> <%- base["04"]["rgb"][2] %>))
(define base05 #(<%- base["05"]["rgb"][0] %> <%- base["05"]["rgb"][1] %> <%- base["05"]["rgb"][2] %>))
(define base06 #(<%- base["06"]["rgb"][0] %> <%- base["06"]["rgb"][1] %> <%- base["06"]["rgb"][2] %>))
(define base07 #(<%- base["07"]["rgb"][0] %> <%- base["07"]["rgb"][1] %> <%- base["07"]["rgb"][2] %>))
(define base08 #(<%- base["08"]["rgb"][0] %> <%- base["08"]["rgb"][1] %> <%- base["08"]["rgb"][2] %>))
(define base09 #(<%- base["09"]["rgb"][0] %> <%- base["09"]["rgb"][1] %> <%- base["09"]["rgb"][2] %>))
(define base0A #(<%- base["0A"]["rgb"][0] %> <%- base["0A"]["rgb"][1] %> <%- base["0A"]["rgb"][2] %>))
(define base0B #(<%- base["0B"]["rgb"][0] %> <%- base["0B"]["rgb"][1] %> <%- base["0B"]["rgb"][2] %>))
(define base0C #(<%- base["0C"]["rgb"][0] %> <%- base["0C"]["rgb"][1] %> <%- base["0C"]["rgb"][2] %>))
(define base0D #(<%- base["0D"]["rgb"][0] %> <%- base["0D"]["rgb"][1] %> <%- base["0D"]["rgb"][2] %>))
(define base0E #(<%- base["0E"]["rgb"][0] %> <%- base["0E"]["rgb"][1] %> <%- base["0E"]["rgb"][2] %>))
(define base0F #(<%- base["0F"]["rgb"][0] %> <%- base["0F"]["rgb"][1] %> <%- base["0F"]["rgb"][2] %>))

(define framework:color-schemes
  `(#hash((name . "Base16 <%- scheme %> Dark")
          (white-on-black-base? . #t)
          (colors
           .
	   ((drracket:syncheck:matching-identifiers            ,base03)
            (framework:basic-canvas-background                 ,base00)
            (framework:default-text-color                      ,base05)
            (framework:misspelled-text-color                   ,base08)
            (framework:paren-match-color                       ,base03)
            (drracket:check-syntax:both-obligation-style-pref  ,base0F)
            (drracket:check-syntax:free-variable               ,base0E)
            (drracket:check-syntax:imported                    ,base0D)
            (drracket:check-syntax:lexically-bound             ,base0C)
            (drracket:check-syntax:my-obligation-style-pref    ,base09)
            (drracket:check-syntax:set!d                       ,base0B)
            (drracket:check-syntax:their-obligation-style-pref ,base0A)
            (drracket:check-syntax:unk-obligation-style-pref   ,base08)
            (drracket:check-syntax:unused-require              ,base08)
            (drracket:read-eval-print-loop:error-color         ,base08)
            (drracket:read-eval-print-loop:out-color           ,base09)
            (drracket:read-eval-print-loop:value-color         ,base0D)
            (framework:syntax-color:scheme:comment             ,base03)
            (framework:syntax-color:scheme:constant            ,base09)
            (framework:syntax-color:scheme:error               ,base08)
            (framework:syntax-color:scheme:hash-colon-keyword  ,base0C)
            (framework:syntax-color:scheme:keyword             ,base0E)
            (framework:syntax-color:scheme:other               ,base05)
            (framework:syntax-color:scheme:parenthesis         ,base04)
            (framework:syntax-color:scheme:string              ,base0B)
            (framework:syntax-color:scheme:symbol              ,base0D)
            (framework:syntax-color:scheme:text                ,base05)
            (plt:htdp:test-coverage-off                        ,base08)
            (plt:htdp:test-coverage-on                         ,base0B)
            (plt:module-language:test-coverage-off             ,base08)
            (plt:module-language:test-coverage-on              ,base0B))))
    #hash((name . "Base16 <%- scheme %> Light")
          (white-on-black-base? . #f)
          (colors
           .
           ((drracket:syncheck:matching-identifiers            ,base03)
            (framework:basic-canvas-background                 ,base07)
            (framework:default-text-color                      ,base02)
            (framework:misspelled-text-color                   ,base08)
            (framework:paren-match-color                       ,base05)
            (drracket:check-syntax:both-obligation-style-pref  ,base0F)
            (drracket:check-syntax:free-variable               ,base0E)
            (drracket:check-syntax:imported                    ,base0D)
            (drracket:check-syntax:lexically-bound             ,base0C)
            (drracket:check-syntax:my-obligation-style-pref    ,base09)
            (drracket:check-syntax:set!d                       ,base0B)
            (drracket:check-syntax:their-obligation-style-pref ,base0B)
            (drracket:check-syntax:unk-obligation-style-pref   ,base08)
            (drracket:check-syntax:unused-require              ,base08)
            (drracket:read-eval-print-loop:error-color         ,base08)
            (drracket:read-eval-print-loop:out-color           ,base09)
            (drracket:read-eval-print-loop:value-color         ,base0D)
            (framework:syntax-color:scheme:comment             ,base03)
            (framework:syntax-color:scheme:constant            ,base09)
            (framework:syntax-color:scheme:error               ,base08)
            (framework:syntax-color:scheme:hash-colon-keyword  ,base0C)
            (framework:syntax-color:scheme:keyword             ,base0E)
            (framework:syntax-color:scheme:other               ,base02)
            (framework:syntax-color:scheme:parenthesis         ,base03)
            (framework:syntax-color:scheme:string              ,base0B)
            (framework:syntax-color:scheme:symbol              ,base0D)
            (framework:syntax-color:scheme:text                ,base02)
            (plt:htdp:test-coverage-off                        ,base08)
            (plt:htdp:test-coverage-on                         ,base0B)
            (plt:module-language:test-coverage-off             ,base08)
            (plt:module-language:test-coverage-on              ,base0B))))))
