<?xml version="1.0" encoding="utf-8"?>
<key name="Software">
	<key name="ConEmu">
      <value name="ColorTable00" type="dword" data="00<%- base["07"]["hexbgr"] %>"/>
      <value name="ColorTable01" type="dword" data="00<%- base["0D"]["hexbgr"] %>"/>
      <value name="ColorTable02" type="dword" data="00<%- base["0B"]["hexbgr"] %>"/>
      <value name="ColorTable03" type="dword" data="00<%- base["0C"]["hexbgr"] %>"/>
      <value name="ColorTable04" type="dword" data="00<%- base["09"]["hexbgr"] %>"/>
      <value name="ColorTable05" type="dword" data="00<%- base["0E"]["hexbgr"] %>"/>
      <value name="ColorTable06" type="dword" data="00<%- base["0A"]["hexbgr"] %>"/>
      <value name="ColorTable07" type="dword" data="00<%- base["03"]["hexbgr"] %>"/>
      <value name="ColorTable08" type="dword" data="00<%- base["04"]["hexbgr"] %>"/>
      <value name="ColorTable09" type="dword" data="00<%- base["0D"]["hexbgr"] %>"/>
      <value name="ColorTable10" type="dword" data="00<%- base["0B"]["hexbgr"] %>"/>
      <value name="ColorTable11" type="dword" data="00<%- base["0C"]["hexbgr"] %>"/>
      <value name="ColorTable12" type="dword" data="00<%- base["08"]["hexbgr"] %>"/>
      <value name="ColorTable13" type="dword" data="00<%- base["0F"]["hexbgr"] %>"/>
      <value name="ColorTable14" type="dword" data="00<%- base["0A"]["hexbgr"] %>"/>
      <value name="ColorTable15" type="dword" data="00<%- base["00"]["hexbgr"] %>"/>
      <value name="ColorTable16" type="dword" data="00<%- base["07"]["hexbgr"] %>"/>
      <value name="ColorTable17" type="dword" data="00<%- base["0D"]["hexbgr"] %>"/>
      <value name="ColorTable18" type="dword" data="00<%- base["0B"]["hexbgr"] %>"/>
      <value name="ColorTable19" type="dword" data="00<%- base["0C"]["hexbgr"] %>"/>
      <value name="ColorTable20" type="dword" data="00<%- base["09"]["hexbgr"] %>"/>
      <value name="ColorTable21" type="dword" data="00<%- base["0E"]["hexbgr"] %>"/>
      <value name="ColorTable22" type="dword" data="00<%- base["0A"]["hexbgr"] %>"/>
      <value name="ColorTable23" type="dword" data="00<%- base["03"]["hexbgr"] %>"/>
      <value name="ColorTable24" type="dword" data="00<%- base["04"]["hexbgr"] %>"/>
      <value name="ColorTable25" type="dword" data="00<%- base["0D"]["hexbgr"] %>"/>
      <value name="ColorTable26" type="dword" data="00<%- base["0B"]["hexbgr"] %>"/>
      <value name="ColorTable27" type="dword" data="00<%- base["0C"]["hexbgr"] %>"/>
      <value name="ColorTable28" type="dword" data="00<%- base["08"]["hexbgr"] %>"/>
      <value name="ColorTable29" type="dword" data="00<%- base["0F"]["hexbgr"] %>"/>
      <value name="ColorTable30" type="dword" data="00<%- base["0A"]["hexbgr"] %>"/>
      <value name="ColorTable31" type="dword" data="00<%- base["00"]["hexbgr"] %>"/>
    </key>
</key>
