/*

    Name:       Base16 <%- scheme %> Light
    Author:     <%- author %>

    Pygments template by Jan T. Sott (https://github.com/idleberg)
    Created with Base16 Builder by Chris Kempson (https://github.com/chriskempson/base16-builder)

*/
.syntax .hll { background-color: #<%- base["06"]["hex"] %> }
.syntax  { background: #<%- base["07"]["hex"] %>; color: #<%- base["00"]["hex"] %> }
.syntax .c { color: #<%- base["04"]["hex"] %> } /* Comment */
.syntax .err { color: #<%- base["08"]["hex"] %> } /* Error */
.syntax .k { color: #<%- base["0E"]["hex"] %> } /* Keyword */
.syntax .l { color: #<%- base["09"]["hex"] %> } /* Literal */
.syntax .n { color: #<%- base["00"]["hex"] %> } /* Name */
.syntax .o { color: #<%- base["0C"]["hex"] %> } /* Operator */
.syntax .p { color: #<%- base["00"]["hex"] %> } /* Punctuation */
.syntax .cm { color: #<%- base["04"]["hex"] %> } /* Comment.Multiline */
.syntax .cp { color: #<%- base["04"]["hex"] %> } /* Comment.Preproc */
.syntax .c1 { color: #<%- base["04"]["hex"] %> } /* Comment.Single */
.syntax .cs { color: #<%- base["04"]["hex"] %> } /* Comment.Special */
.syntax .gd { color: #<%- base["08"]["hex"] %> } /* Generic.Deleted */
.syntax .ge { font-style: italic } /* Generic.Emph */
.syntax .gh { color: #<%- base["00"]["hex"] %>; font-weight: bold } /* Generic.Heading */
.syntax .gi { color: #<%- base["0B"]["hex"] %> } /* Generic.Inserted */
.syntax .gp { color: #<%- base["04"]["hex"] %>; font-weight: bold } /* Generic.Prompt */
.syntax .gs { font-weight: bold } /* Generic.Strong */
.syntax .gu { color: #<%- base["0C"]["hex"] %>; font-weight: bold } /* Generic.Subheading */
.syntax .kc { color: #<%- base["0E"]["hex"] %> } /* Keyword.Constant */
.syntax .kd { color: #<%- base["0E"]["hex"] %> } /* Keyword.Declaration */
.syntax .kn { color: #<%- base["0C"]["hex"] %> } /* Keyword.Namespace */
.syntax .kp { color: #<%- base["0E"]["hex"] %> } /* Keyword.Pseudo */
.syntax .kr { color: #<%- base["0E"]["hex"] %> } /* Keyword.Reserved */
.syntax .kt { color: #<%- base["0A"]["hex"] %> } /* Keyword.Type */
.syntax .ld { color: #<%- base["0B"]["hex"] %> } /* Literal.Date */
.syntax .m { color: #<%- base["09"]["hex"] %> } /* Literal.Number */
.syntax .s { color: #<%- base["0B"]["hex"] %> } /* Literal.String */
.syntax .na { color: #<%- base["0D"]["hex"] %> } /* Name.Attribute */
.syntax .nb { color: #<%- base["00"]["hex"] %> } /* Name.Builtin */
.syntax .nc { color: #<%- base["0A"]["hex"] %> } /* Name.Class */
.syntax .no { color: #<%- base["08"]["hex"] %> } /* Name.Constant */
.syntax .nd { color: #<%- base["0C"]["hex"] %> } /* Name.Decorator */
.syntax .ni { color: #<%- base["00"]["hex"] %> } /* Name.Entity */
.syntax .ne { color: #<%- base["08"]["hex"] %> } /* Name.Exception */
.syntax .nf { color: #<%- base["0D"]["hex"] %> } /* Name.Function */
.syntax .nl { color: #<%- base["00"]["hex"] %> } /* Name.Label */
.syntax .nn { color: #<%- base["0A"]["hex"] %> } /* Name.Namespace */
.syntax .nx { color: #<%- base["0D"]["hex"] %> } /* Name.Other */
.syntax .py { color: #<%- base["00"]["hex"] %> } /* Name.Property */
.syntax .nt { color: #<%- base["0C"]["hex"] %> } /* Name.Tag */
.syntax .nv { color: #<%- base["08"]["hex"] %> } /* Name.Variable */
.syntax .ow { color: #<%- base["0C"]["hex"] %> } /* Operator.Word */
.syntax .w { color: #<%- base["00"]["hex"] %> } /* Text.Whitespace */
.syntax .mf { color: #<%- base["09"]["hex"] %> } /* Literal.Number.Float */
.syntax .mh { color: #<%- base["09"]["hex"] %> } /* Literal.Number.Hex */
.syntax .mi { color: #<%- base["09"]["hex"] %> } /* Literal.Number.Integer */
.syntax .mo { color: #<%- base["09"]["hex"] %> } /* Literal.Number.Oct */
.syntax .sb { color: #<%- base["0B"]["hex"] %> } /* Literal.String.Backtick */
.syntax .sc { color: #<%- base["00"]["hex"] %> } /* Literal.String.Char */
.syntax .sd { color: #<%- base["04"]["hex"] %> } /* Literal.String.Doc */
.syntax .s2 { color: #<%- base["0B"]["hex"] %> } /* Literal.String.Double */
.syntax .se { color: #<%- base["09"]["hex"] %> } /* Literal.String.Escape */
.syntax .sh { color: #<%- base["0B"]["hex"] %> } /* Literal.String.Heredoc */
.syntax .si { color: #<%- base["09"]["hex"] %> } /* Literal.String.Interpol */
.syntax .sx { color: #<%- base["0B"]["hex"] %> } /* Literal.String.Other */
.syntax .sr { color: #<%- base["0B"]["hex"] %> } /* Literal.String.Regex */
.syntax .s1 { color: #<%- base["0B"]["hex"] %> } /* Literal.String.Single */
.syntax .ss { color: #<%- base["0B"]["hex"] %> } /* Literal.String.Symbol */
.syntax .bp { color: #<%- base["00"]["hex"] %> } /* Name.Builtin.Pseudo */
.syntax .vc { color: #<%- base["08"]["hex"] %> } /* Name.Variable.Class */
.syntax .vg { color: #<%- base["08"]["hex"] %> } /* Name.Variable.Global */
.syntax .vi { color: #<%- base["08"]["hex"] %> } /* Name.Variable.Instance */
.syntax .il { color: #<%- base["09"]["hex"] %> } /* Literal.Number.Integer.Long */
