/*

    Name:       Base16 <%- scheme %> Light
    Author:     <%- author %>

    Chrome Developer Tools template by Jan T. Sott
    Based on a Gist by Ben Truyman
    Original Base16 color scheme by Chris Kempson

    https://github.com/chriskempson/base16

*/
#-webkit-web-inspector #main {
  background-color: #<%- base["07"]["hex"] %> !important;
}
#-webkit-web-inspector tr {
  color: #<%- base["02"]["hex"] %>;
}
#-webkit-web-inspector ::selection {
  background: #888;
  opacity: 1;
}
#-webkit-web-inspector.compact #toolbar {
  background: -webkit-linear-gradient(#<%- base["04"]["hex"] %>, #<%- base["06"]["hex"] %>) !important;
  border-top: 5px solid #<%- base["0C"]["hex"] %> !important;
  border-bottom: 1px solid #<%- base["05"]["hex"] %> !important;
  padding-top: 0 !important;
  height: 50px !important;
}
#-webkit-web-inspector.compact #toolbar .toolbar-label {
  color: #<%- base["00"]["hex"] %> !important;
}
#-webkit-web-inspector.compact #toolbar .toggled-on .toolbar-label {
  color: #<%- base["00"]["hex"] %> !important;
}
#-webkit-web-inspector.compact #toolbar .toolbar-item {
  padding: 10px 15px !important;
}
#-webkit-web-inspector.compact #toolbar .toolbar-item.toggleable.toggled-on {
  background: -webkit-linear-gradient(#<%- base["05"]["hex"] %>, #<%- base["06"]["hex"] %>) !important;
  padding: 10px 13px !important;
}
#-webkit-web-inspector.compact .toolbar-item.close-left {
  margin-top: 1px !important;
}
#-webkit-web-inspector.compact #toolbar-controls {
  margin-top: -4px !important;
}
#-webkit-web-inspector.compact #toolbar-search-item {
  margin-top: 12px !important;
}
#-webkit-web-inspector.compact #main {
  top: 50px !important;
}
#-webkit-web-inspector.compact #search-results-matches {
  color: #eee !important;
  text-shadow: none !important;
}
#-webkit-web-inspector.compact #search {
  background: #<%- base["07"]["hex"] %> !important;
}
#-webkit-web-inspector .crumbs .crumb {
  display: none;
}
#-webkit-web-inspector .status-bar {
  border-color: #<%- base["05"]["hex"] %> !important;
  background: #<%- base["07"]["hex"] %> !important;
}
#-webkit-web-inspector .status-bar-item {
  border-color: #<%- base["05"]["hex"] %> !important;
  -webkit-filter: grayscale(0.75);
  color: #000000 !important;
  text-shadow: none !important;
}
#-webkit-web-inspector .glyph {
  background-color: #000000 !important;
}
#-webkit-web-inspector .glyph.shadow {
  display: none;
}
#-webkit-web-inspector button.status-bar-item.toggled-on .glyph {
  background-color: #000000 !important;
}
#-webkit-web-inspector #error-warning-count {
  color: #000000 !important;
  margin-right: 5px;
}
#-webkit-web-inspector #error-count-img,
#-webkit-web-inspector #warning-count-img {
  opacity: .5;
  -webkit-filter: grayscale(0.5);
}
#-webkit-web-inspector .scope-bar li {
  margin: 1px 2px 0 !important;
  padding: 2px 5px !important;
  color: #000000 !important;
  text-shadow: none !important;
}
#-webkit-web-inspector .scope-bar li.selected,
#-webkit-web-inspector .scope-bar li:hover,
#-webkit-web-inspector .scope-bar li:active {
  color: #000000 !important;
  background: #333 !important;
}
#-webkit-web-inspector .styles-section,
#-webkit-web-inspector .monospace {
  font-family: 'DejaVu Sans Mono', 'DroidSansMono', Menlo, monospace !important;
}
#-webkit-web-inspector .selector-matches {
  color: #<%- base["0E"]["hex"] %> !important;
}
#-webkit-web-inspector body.inactive .sidebar {
  background-color: #dcdcdc !important;
}
#-webkit-web-inspector .sidebar {
  background-color: #<%- base["07"]["hex"] %> !important;
  color: #<%- base["02"]["hex"] %>;
}
#-webkit-web-inspector .base-storage-tree-element-subtitle {
  color: #3d3d3d !important;
  font-weight: bold;
}
#-webkit-web-inspector .sidebar-tree-section {
  color: #3d3d3d !important;
  text-shadow: black 0 0 0 !important;
}
#-webkit-web-inspector .editing {
  color: #<%- base["00"]["hex"] %> !important;
  background-color: #000 !important;
}
#-webkit-web-inspector .styles-section.read-only {
  background: #b8b8b8 !important;
}
#-webkit-web-inspector .styles-section,
#-webkit-web-inspector .subtitle {
  color: #7C7C7C !important;
}
#-webkit-web-inspector .styles-sidebar-separator,
#-webkit-web-inspector .pane > .title {
  background-image: -webkit-linear-gradient(#555555, #333333) !important;
  border-top-color: #666 !important;
  border-bottom-color: #333 !important;
  color: #bbb !important;
  text-shadow: black 0 1px 0 !important;
  text-overflow: ellipsis !important;
}
#-webkit-web-inspector .pane > .title > button,
#-webkit-web-inspector .pane > .title > select {
  -webkit-filter: invert(1);
}
#-webkit-web-inspector .split-view-sidebar-right {
  background: #222 !important;
}
#-webkit-web-inspector .section > .header::before,
#-webkit-web-inspector .properties-tree li.parent::before,
#-webkit-web-inspector .event-bars .event-bar .header::before,
#-webkit-web-inspector .outline-disclosure li.parent::before,
#-webkit-web-inspector .styles-section.matched-styles .properties li.parent .expand-element {
  content: url(chrome-devtools://devtools/Images/treeRightTriangleWhite.png) !important;
}
#-webkit-web-inspector .styles-section .properties li.parent::before,
#-webkit-web-inspector .styles-section .properties li.parent.expanded::before {
  content: none !important;
}
#-webkit-web-inspector .styles-section.matched-styles .properties li.parent .expand-element {
  margin-right: 1px !important;
  margin-left: -5px !important;
  opacity: 0.6 !important;
}
#-webkit-web-inspector .section.expanded > .header::before,
#-webkit-web-inspector .properties-tree li.parent.expanded::before,
#-webkit-web-inspector .event-bars .event-bar.expanded .header::before,
#-webkit-web-inspector .outline-disclosure li.parent.expanded::before,
#-webkit-web-inspector .styles-section.matched-styles .properties li.parent.expanded .expand-element {
  content: url(chrome-devtools://devtools/Images/treeDownTriangleWhite.png) !important;
}
#-webkit-web-inspector .child-editing {
  color: #<%- base["00"]["hex"] %> !important;
}
#-webkit-web-inspector .section .properties .name,
#-webkit-web-inspector .event-properties .name {
  color: #<%- base["0A"]["hex"] %> !important;
}
#-webkit-web-inspector .styles-selector {
  color: #<%- base["0B"]["hex"] %> !important;
}
#-webkit-web-inspector .section .header {
  color: #CCC !important;
}
#-webkit-web-inspector .properties .value {
  color: #<%- base["0C"]["hex"] %> !important;
}
#-webkit-web-inspector .metrics {
  color: #333 !important;
}
#-webkit-web-inspector .metrics .border {
  border-color: #FFF !important;
}
#-webkit-web-inspector .event-bars .event-bar .header .title {
  color: #969796 !important;
  text-shadow: none !important;
}
#-webkit-web-inspector #console-messages {
  font-family: 'DejaVu Sans Mono', 'DroidSansMono', Menlo, monospace !important;
  background: #<%- base["07"]["hex"] %>;
}
#-webkit-web-inspector #console-messages a {
  color: #666 !important;
}
#-webkit-web-inspector #console-messages a:hover {
  color: #999 !important;
}
#-webkit-web-inspector .console-message {
  color: #F1F1F1 !important;
}
#-webkit-web-inspector .console-message,
#-webkit-web-inspector .console-user-command {
  border-bottom: 1px solid #444 !important;
}
#-webkit-web-inspector .console-user-command > .console-message-text {
  color: #C4C7C6 !important;
}
#-webkit-web-inspector .console-formatted-number {
  color: #<%- base["09"]["hex"] %> !important;
}
#-webkit-web-inspector .console-formatted-string {
  color: #<%- base["09"]["hex"] %> !important;
}
#-webkit-web-inspector .console-formatted-object {
  color: #7C7C7C !important;
}
#-webkit-web-inspector .console-formatted-function {
  color: #<%- base["00"]["hex"] %> !important;
}
#-webkit-web-inspector .console-formatted-regexp {
  color: #<%- base["0E"]["hex"] %> !important;
}
#-webkit-web-inspector .console-group-messages .section .header .title {
  color: #F1F1F1 !important;
}
#-webkit-web-inspector .console-group-messages .section .header::before,
#-webkit-web-inspector .properties-tree li.parent::before {
  content: url(chrome-devtools://devtools/Images/treeRightTriangleWhite.png) !important;
}
#-webkit-web-inspector .console-group-messages .section.expanded .header::before,
#-webkit-web-inspector .properties-tree li.parent.expanded::before {
  content: url(chrome-devtools://devtools/Images/treeDownTriangleWhite.png) !important;
}
@-webkit-keyframes webkit-error-level {
  0% {
    color: #f77 !important;
  }
  50% {
    color: #f22 !important;
  }
  100% {
    color: #f77 !important;
  }
}
#-webkit-web-inspector .console-message-text {
  color: #<%- base["00"]["hex"] %>;
}
#-webkit-web-inspector .console-error-level .console-message-text .title {
  color: #f66 !important;
  -webkit-animation-name: webkit-error-level;
  -webkit-animation-duration: 2s;
  -webkit-animation-iteration-count: infinite;
  -webkit-timing-function: ease-in-out;
}
#-webkit-web-inspector .console-user-command::before {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuMC1jMDYwIDYxLjEzNDc3NywgMjAxMC8wMi8xMi0xNzozMjowMCAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENTNSBNYWNpbnRvc2giIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6OTMzNzdGNUZDMTA1MTFFMDgwRUZGQ0JCMjgzMzU0MTYiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6OTMzNzdGNjBDMTA1MTFFMDgwRUZGQ0JCMjgzMzU0MTYiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6aW5zdGFuY2VJRD0ieG1wLmlpZDo5MzM3N0Y1REMxMDUxMUUwODBFRkZDQkIyODMzNTQxNiIgc3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDo5MzM3N0Y1RUMxMDUxMUUwODBFRkZDQkIyODMzNTQxNiIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94cGFja2V0IGVuZD0iciI/Pia6udAAAAB5SURBVHjaYvz//z8DMYAFxli9ejWI6oByK5AVhYaGIhRCgQsQGwOxIFTxe5gEE5pCVyA+C8RpQLwbqgmrwvdQxauhis6AbMamEASUkEwCabyHTWE51BQlqBNMoDSKQhckX3dCFd3DCB4g2AP16VkoGwUwEhvgAAEGAAzQHBRSxqPRAAAAAElFTkSuQmCC) !important;
}
#-webkit-web-inspector #console-prompt {
  color: #F1F1F1 !important;
}
#-webkit-web-inspector #console-prompt::before {
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAoAAAAKCAYAAACNMs+9AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuMC1jMDYwIDYxLjEzNDc3NywgMjAxMC8wMi8xMi0xNzozMjowMCAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENTNSBNYWNpbnRvc2giIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6MjRGNTc2MTZDMTA2MTFFMDgwRUZGQ0JCMjgzMzU0MTYiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6MjRGNTc2MTdDMTA2MTFFMDgwRUZGQ0JCMjgzMzU0MTYiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6aW5zdGFuY2VJRD0ieG1wLmlpZDo5MzM3N0Y2MUMxMDUxMUUwODBFRkZDQkIyODMzNTQxNiIgc3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDo5MzM3N0Y2MkMxMDUxMUUwODBFRkZDQkIyODMzNTQxNiIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94cGFja2V0IGVuZD0iciI/Plf0eOsAAAB4SURBVHjaYvz//z8DMYAFxph+BqyhA8qtQFaUacKIUAgFLkBsDMSCUMXvYRJMaApdgfgsEKcB8W6oJqwK30MVr4YqOgPEodgUgoASkkkgjfewKSyHmqIEdYIJlEZR6ILk606oonsYwQMEe6A+PQtlowBGYgMcIMAAF2wcFPVNZx8AAAAASUVORK5CYII=) !important;
  color: #<%- base["00"]["hex"] %> !important;
}
#-webkit-web-inspector .console-formatted-number {
  color: #<%- base["09"]["hex"] %> !important;
}
#-webkit-web-inspector .console-formatted-string {
  color: #<%- base["09"]["hex"] %> !important;
}
#-webkit-web-inspector .console-formatted-object,
#-webkit-web-inspector .console-formatted-node,
#-webkit-web-inspector .console-formatted-array {
  color: #7C7C7C !important;
}
#-webkit-web-inspector .console-formatted-function {
  color: #<%- base["00"]["hex"] %> !important;
}
#-webkit-web-inspector .console-formatted-regexp {
  color: #<%- base["0E"]["hex"] %> !important;
}
#-webkit-web-inspector .script-view,
#-webkit-web-inspector .properties-tree,
#-webkit-web-inspector .pane,
#-webkit-web-inspector .breakpoint-list li,
#-webkit-web-inspector .pane > .body .info {
  color: #CCC !important;
}
#-webkit-web-inspector .script-view,
#-webkit-web-inspector .text-editor-contents,
#-webkit-web-inspector .pane.expanded,
#-webkit-web-inspector #elements-content,
#-webkit-web-inspector .resource-view.json {
  background: #<%- base["07"]["hex"] %> !important;
  font-size: 12px !important;
}
#-webkit-web-inspector .highlight {
  color: #F1F1F1;
}
#-webkit-web-inspector li.hovered:not(.selected) .selection {
  background: rgba(255, 255, 255, 0.2) !important;
}
#-webkit-web-inspector #elements-content .selected {
  background-color: #8a8a8a !important;
}
#-webkit-web-inspector .base-navigator-tree-element-title {
  color: #<%- base["02"]["hex"] %>;
}
#-webkit-web-inspector .tabbed-pane-header,
#-webkit-web-inspector .navigator-tabbed-pane .tabbed-pane-header {
  background-image: -webkit-linear-gradient(#<%- base["04"]["hex"] %>, #<%- base["06"]["hex"] %>) !important;
}
#-webkit-web-inspector .tabbed-pane-header-tab {
  color: #bbb !important;
  text-shadow: black 0 1px 0 !important;
}
#-webkit-web-inspector .tabbed-pane-header-tab.selected {
  background-color: #<%- base["07"]["hex"] %> !important;
  color: #<%- base["02"]["hex"] %> !important;
}
#-webkit-web-inspector #scripts-editor-container-tabbed-pane .tabbed-pane-header {
  background-image: -webkit-linear-gradient(#<%- base["04"]["hex"] %>, #<%- base["06"]["hex"] %>) !important;
}
#-webkit-web-inspector .tabbed-pane-header-tab-close-button {
  color: #<%- base["02"]["hex"] %> !important;
}
#-webkit-web-inspector .tabbed-pane-content {
  background: #<%- base["07"]["hex"] %> !important;
  color: #<%- base["02"]["hex"] %> !important;
}
#-webkit-web-inspector .outline-disclosure li.selected .selection {
  background-color: #8a8a8a !important;
}
#-webkit-web-inspector .outline-disclosure ol:focus li.selected .selection {
  background-color: #3879d9 !important;
}
#-webkit-web-inspector .header-toggle:hover {
  color: #<%- base["0D"]["hex"] %> !important;
}
#-webkit-web-inspector .header-value.source-code {
  color: white !important;
}
#-webkit-web-inspector .webkit-html-comment {
  color: #<%- base["04"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-html-tag {
  color: #<%- base["08"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-html-attribute-name {
  color: #<%- base["09"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-html-attribute-value {
  color: #<%- base["0B"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-html-text-node .webkit-html-css-node {
  color: #<%- base["09"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-html-js-node {
  color: #<%- base["0E"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-html-resource-link,
#-webkit-web-inspector .webkit-html-external-link {
  color: #<%- base["0D"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-css-comment {
  color: #<%- base["04"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-css-selector,
#-webkit-web-inspector .styles-selector {
  color: #<%- base["0B"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-css-property {
  color: #<%- base["0A"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-css-keyword {
  color: #<%- base["08"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-css-number,
#-webkit-web-inspector .properties-tree .value {
  color: #<%- base["09"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-css-important,
#-webkit-web-inspector .webkit-css-at-rule {
  color: #<%- base["0E"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-css-string {
  color: #<%- base["0C"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-css-url {
  color: #<%- base["0D"]["hex"] %> !important;
}
#-webkit-web-inspector .sidebar-separator {
  padding: 3px 5px 5px !important;
  background: #b8b8b8 !important;
  color: #b3b3b3 !important;
  text-shadow: none !important;
}
#-webkit-web-inspector .webkit-line-content,
#-webkit-web-inspector .webkit-javascript-ident {
  color: #<%- base["00"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-javascript-keyword {
  color: #<%- base["08"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-javascript-comment {
  color: #<%- base["04"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-javascript-string {
  color: #<%- base["09"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-javascript-number {
  color: #<%- base["09"]["hex"] %> !important;
}
#-webkit-web-inspector .webkit-javascript-regexp {
  color: #<%- base["0E"]["hex"] %> !important;
}
#-webkit-web-inspector .section .properties .name,
#-webkit-web-inspector .event-properties .name {
  color: #<%- base["0A"]["hex"] %> !important;
}
#-webkit-web-inspector .popover {
  background-color: rgba(0, 0, 0, 0.9) !important;
  border: 10px solid rgba(0, 0, 0, 0.9) !important;
  border-radius: 10px !important;
  -webkit-border-image: none !important;
  margin-left: 10px !important;
}
#-webkit-web-inspector .popover .arrow {
  background-image: none !important;
  border-color: transparent transparent #000 transparent !important;
  border-style: solid;
  border-width: 10px;
  width: 0 !important;
  height: 0 !important;
  bottom: -2px !important;
  left: 0;
}
#-webkit-web-inspector .popover.bottom-left-arrow .arrow,
#-webkit-web-inspector .popover.bottom-right-arrow .arrow {
  border-color: #000 transparent transparent transparent !important;
}
#-webkit-web-inspector .popover.left-top-arrow .arrow,
#-webkit-web-inspector .popover.left-bottom-arrow .arrow {
  border-color: transparent #000 transparent transparent !important;
}
#-webkit-web-inspector .popover.right-top-arrow .arrow,
#-webkit-web-inspector .popover.right-bottom-arrow .arrow {
  border-color: transparent transparent #000 transparent !important;
}
#-webkit-web-inspector .popover .source-frame-popover-title {
  color: #<%- base["00"]["hex"] %> !important;
}
#-webkit-web-inspector .popover .source-frame-popover-tree {
  border-top-color: #444 !important;
}
#-webkit-web-inspector .custom-popup-vertical-scroll ::-webkit-scrollbar-track-piece:vertical:decrement,
#-webkit-web-inspector .custom-popup-vertical-scroll ::-webkit-scrollbar-track-piece:vertical:increment {
  background: #333 !important;
  border-radius: 5px !important;
}
#-webkit-web-inspector .popover table.image-preview-container .description {
  color: #<%- base["09"]["hex"] %>;
}
#-webkit-web-inspector .network-log-grid.data-grid th,
#-webkit-web-inspector .network-log-grid.data-grid th.sort-descending,
#-webkit-web-inspector .network-log-grid.data-grid th.sort-ascending {
  background: -webkit-linear-gradient(#<%- base["04"]["hex"] %>, #<%- base["06"]["hex"] %>) !important;
  color: white !important;
}
#-webkit-web-inspector .network-item {
  color: #<%- base["02"]["hex"] %>;
}
#-webkit-web-inspector .network-log-grid.data-grid tr.filler {
  background-color: #<%- base["07"]["hex"] %> !important;
}
#-webkit-web-inspector .network-timing-bar-title {
  color: #<%- base["02"]["hex"] %> !important;
}
#-webkit-web-inspector #timeline-overview-sidebar {
  background: -webkit-linear-gradient(#<%- base["04"]["hex"] %>, #<%- base["06"]["hex"] %>) !important;
}
#-webkit-web-inspector #timeline-overview-sidebar .sidebar-tree-item {
  color: #<%- base["02"]["hex"] %> !important;
}
#-webkit-web-inspector #timeline-overview-sidebar .sidebar-tree-item.selected {
  color: white !important;
}
#-webkit-web-inspector #timeline-overview-separator {
  background: -webkit-linear-gradient(#<%- base["04"]["hex"] %>, #<%- base["06"]["hex"] %>) !important;
  border-top: 1px solid #<%- base["0C"]["hex"] %> !important;
  border-bottom: 1px solid #<%- base["05"]["hex"] %> !important;
}
#-webkit-web-inspector .timeline-details-title {
  color: #<%- base["02"]["hex"] %>;
}
#-webkit-web-inspector .timeline-details {
  color: white;
}
#-webkit-web-inspector .timeline-details-row-title {
  color: #<%- base["05"]["hex"] %>;
}
#-webkit-web-inspector .timeline-details-row-data {
  color: #<%- base["02"]["hex"] %>;
}
#-webkit-web-inspector .timeline-graph-side.even {
  background-color: rgba(0, 0, 0, 0.5) !important;
}
#-webkit-web-inspector .resources-divider-label-bar {
  background-color: #dcdcdc !important;
}
#-webkit-web-inspector .network-timeline-grid .resources-divider {
  background-color: #000000 !important;
}
#-webkit-web-inspector .network-log-grid.data-grid select {
  color: white;
}
#-webkit-web-inspector .resources-divider-label,
#-webkit-web-inspector .network-timeline-grid .resources-divider-label {
  color: #<%- base["02"]["hex"] %> !important;
}
#-webkit-web-inspector .network-graph-label {
  color: #<%- base["02"]["hex"] %> !important;
  text-shadow: rgba(0, 0, 0, 0.25) 1px 0 0, rgba(0, 0, 0, 0.25) -1px 0 0, rgba(0, 0, 0, 0.333) 0 1px 0, rgba(0, 0, 0, 0.25) 0 -1px 0 !important;
}
#-webkit-web-inspector .timeline-tree-item .data.dimmed {
  color: #000000 !important;
}
#-webkit-web-inspector .resources.panel .sidebar li {
  color: #0a0a0a;
}
#-webkit-web-inspector .resource-view {
  background-color: #<%- base["07"]["hex"] %>;
}
#-webkit-web-inspector .resource-view .title {
  color: white;
}
#-webkit-web-inspector .resource-view .infoList dt {
  color: #<%- base["05"]["hex"] %> !important;
}
#-webkit-web-inspector .resource-view .infoList dd {
  color: #<%- base["02"]["hex"] %>;
}
#-webkit-web-inspector .resource-view.font,
#-webkit-web-inspector .resource-view.html iframe body {
  color: white !important;
}
#-webkit-web-inspector .text-editor-lines {
  background-color: #e8e8e8 !important;
  border-right: 2px solid #000000 !important;
}
#-webkit-web-inspector .text-editor-lines .webkit-line-number {
  color: #0a0a0a;
}
#-webkit-web-inspector .storage-view {
  background-color: #<%- base["07"]["hex"] %>;
}
#-webkit-web-inspector .storage-empty-view {
  color: white;
}
#-webkit-web-inspector .data-grid th {
  background-image: none !important;
  background: -webkit-linear-gradient(#<%- base["04"]["hex"] %>, #<%- base["06"]["hex"] %>) !important;
}
#-webkit-web-inspector .data-grid table.data {
  background-image: -webkit-gradient(linear, left top, left bottom, from(#000000), color-stop(0.5, #000000), color-stop(0.5, #<%- base["07"]["hex"] %>), to(#<%- base["07"]["hex"] %>)) !important;
}
#-webkit-web-inspector #settings-screen .help-window-main,
#-webkit-web-inspector #drawer-contents .help-window-main,
#-webkit-web-inspector .help-window-outer .tabbed-pane-header {
  color: white !important;
  background-color: #<%- base["07"]["hex"] %> !important;
}
#-webkit-web-inspector .settings-tab .help-section-title,
#-webkit-web-inspector .help-key {
  color: #<%- base["0C"]["hex"] %> !important;
}
#-webkit-web-inspector .help-key-delimiter {
  color: #<%- base["0E"]["hex"] %> !important;
}
#-webkit-web-inspector .styles-element-state-pane {
  background: #b8b8b8 !important;
}
#-webkit-web-inspector .placard:nth-of-type(2n) {
  background: #333 !important;
}
#-webkit-web-inspector .placard.selected {
  background-image: -webkit-linear-gradient(#<%- base["0C"]["hex"] %>, #335e57) !important;
  border-top-color: #335e57 !important;
}
#-webkit-web-inspector .placard .title {
  color: #CCC !important;
}
#-webkit-web-inspector .placard .subtitle {
  color: rgba(255, 255, 255, 0.7) !important;
}
#-webkit-web-inspector .webkit-execution-line.webkit-line-content {
  background-color: #b8b8b8 !important;
  outline: 1px solid #919191 !important;
}
