/*

    Name:       Base16 <%- scheme %> Light
    Author:     <%- author %>

    CodeMirror template adapted for IPython Notebook by Nikhil Sonnad (https://github.com/nsonnad/base16-ipython-notebook)
    CodeMirror template by Jan T. Sott (https://github.com/idleberg/base16-chrome-devtools)
    Original Base16 color scheme by Chris Kempson (https://github.com/chriskempson/base16)

*/

/* Uncomment to use a custom font
div#notebook, div.CodeMirror, div.output_area pre, div.output_wrapper, div.prompt {
  font-family: 'Custom Font Name', monospace !important;
}
*/

/* GLOBALS */
body {background-color: #<%- base["07"]["hex"] %>;}
a {color: #<%- base["0D"]["hex"] %>;}

/* INTRO PAGE */
.toolbar_info, .list-container {color: #<%- base["01"]["hex"] %>;}

/* NOTEBOOK */

/* comment out this line to bring the toolbar back */
div#maintoolbar, div#header {display: none !important;}

div#notebook {border-top: none;}

div.input_prompt {color: #<%- base["0E"]["hex"] %>;}
div.output_prompt {color: #<%- base["0F"]["hex"] %>;}
div.input_area {
  border-radius: 0px;
  border: 1px solid #<%- base["05"]["hex"] %>;
}
div.output_area pre {font-weight: normal; color: #<%- base["02"]["hex"] %>;}

.rendered_html table, .rendered_html th, .rendered_html tr, .rendered_html td {
  border: 1px  #<%- base["03"]["hex"] %> solid;
  color: #<%- base["03"]["hex"] %>;
}
div.output_html { font-family: sans-serif; }
table.dataframe tr {border: 1px #<%- base["02"]["hex"] %>;}

div.cell.selected {border-radius: 0px;}
div.cell.edit_mode {border-radius: 0px; border: thin solid #<%- base["0F"]["hex"] %>;}
div.text_cell_render, div.output_html {color: #<%- base["02"]["hex"] %>;}

span.ansiblack {color: #<%- base["01"]["hex"] %>;}
span.ansiblue {color: #<%- base["0C"]["hex"] %>;}
span.ansigray {color: #<%- base["04"]["hex"] %>;}
span.ansigreen {color: #<%- base["0B"]["hex"] %>;}
span.ansipurple {color: #<%- base["0E"]["hex"] %>;}
span.ansired {color: #<%- base["08"]["hex"] %>;}
span.ansiyellow {color: #<%- base["0A"]["hex"] %>;}

div.output_stderr {background-color: #<%- base["08"]["hex"] %>;}
div.output_stderr pre {color: #<%- base["06"]["hex"] %>;}

.cm-s-ipython.CodeMirror {background: #<%- base["07"]["hex"] %>; color: #<%- base["01"]["hex"] %>;}
.cm-s-ipython div.CodeMirror-selected {background: #<%- base["06"]["hex"] %> !important;}
.cm-s-ipython .CodeMirror-gutters {background: #<%- base["07"]["hex"] %>; border-right: 0px;}
.cm-s-ipython .CodeMirror-linenumber {color: #<%- base["04"]["hex"] %>;}
.cm-s-ipython .CodeMirror-cursor {border-left: 1px solid #<%- base["03"]["hex"] %> !important;}

.cm-s-ipython span.cm-comment {color: #<%- base["0F"]["hex"] %>;}
.cm-s-ipython span.cm-atom {color: #<%- base["0E"]["hex"] %>;}
.cm-s-ipython span.cm-number {color: #<%- base["0E"]["hex"] %>;}

.cm-s-ipython span.cm-property, .cm-s-ipython span.cm-attribute {color: #<%- base["0B"]["hex"] %>;}
.cm-s-ipython span.cm-keyword {color: #<%- base["08"]["hex"] %>;}
.cm-s-ipython span.cm-string {color: #<%- base["0A"]["hex"] %>;}
.cm-s-ipython span.cm-operator {color: #<%- base["0F"]["hex"] %>;}
.cm-s-ipython span.cm-builtin {color: #<%- base["0E"]["hex"] %>;}

.cm-s-ipython span.cm-variable {color: #<%- base["0B"]["hex"] %>;}
.cm-s-ipython span.cm-variable-2 {color: #<%- base["0D"]["hex"] %>;}
.cm-s-ipython span.cm-def {color: #<%- base["09"]["hex"] %>;}
.cm-s-ipython span.cm-error {background: #<%- base["08"]["hex"] %>; color: #<%- base["03"]["hex"] %>;}
.cm-s-ipython span.cm-bracket {color: #<%- base["02"]["hex"] %>;}
.cm-s-ipython span.cm-tag {color: #<%- base["08"]["hex"] %>;}
.cm-s-ipython span.cm-link {color: #<%- base["0E"]["hex"] %>;}

.cm-s-ipython .CodeMirror-matchingbracket { text-decoration: underline; color: #<%- base["01"]["hex"] %> !important;}
