/*

    Name:       Base16 <%- scheme %> Dark
    Author:     <%- author %>

    CodeMirror template by Jan T. Sott (https://github.com/idleberg)
    Original Base16 color scheme by Chris Kempson (https://github.com/chriskempson/base16)

*/

.cm-s-base16-<%- schemeSlug %>-dark.CodeMirror {background: #<%- base["00"]["hex"] %>; color: #<%- base["06"]["hex"] %>;}
.cm-s-base16-<%- schemeSlug %>-dark div.CodeMirror-selected {background: #<%- base["01"]["hex"] %> !important;}
.cm-s-base16-<%- schemeSlug %>-dark .CodeMirror-gutters {background: #<%- base["00"]["hex"] %>; border-right: 0px;}
.cm-s-base16-<%- schemeSlug %>-dark .CodeMirror-linenumber {color: #<%- base["03"]["hex"] %>;}
.cm-s-base16-<%- schemeSlug %>-dark .CodeMirror-cursor {border-left: 1px solid #<%- base["04"]["hex"] %> !important;}

.cm-s-base16-<%- schemeSlug %>-dark span.cm-comment {color: #<%- base["0F"]["hex"] %>;}
.cm-s-base16-<%- schemeSlug %>-dark span.cm-atom {color: #<%- base["0E"]["hex"] %>;}
.cm-s-base16-<%- schemeSlug %>-dark span.cm-number {color: #<%- base["0E"]["hex"] %>;}

.cm-s-base16-<%- schemeSlug %>-dark span.cm-property, .cm-s-base16-<%- schemeSlug %>-dark span.cm-attribute {color: #<%- base["0B"]["hex"] %>;}
.cm-s-base16-<%- schemeSlug %>-dark span.cm-keyword {color: #<%- base["08"]["hex"] %>;}
.cm-s-base16-<%- schemeSlug %>-dark span.cm-string {color: #<%- base["0A"]["hex"] %>;}

.cm-s-base16-<%- schemeSlug %>-dark span.cm-variable {color: #<%- base["0B"]["hex"] %>;}
.cm-s-base16-<%- schemeSlug %>-dark span.cm-variable-2 {color: #<%- base["0D"]["hex"] %>;}
.cm-s-base16-<%- schemeSlug %>-dark span.cm-def {color: #<%- base["09"]["hex"] %>;}
.cm-s-base16-<%- schemeSlug %>-dark span.cm-error {background: #<%- base["08"]["hex"] %>; color: #<%- base["04"]["hex"] %>;}
.cm-s-base16-<%- schemeSlug %>-dark span.cm-bracket {color: #<%- base["06"]["hex"] %>;}
.cm-s-base16-<%- schemeSlug %>-dark span.cm-tag {color: #<%- base["08"]["hex"] %>;}
.cm-s-base16-<%- schemeSlug %>-dark span.cm-link {color: #<%- base["0E"]["hex"] %>;}

.cm-s-base16-<%- schemeSlug %>-dark .CodeMirror-matchingbracket { text-decoration: underline; color: white !important;}
.cm-s-base16-<%= @slug %>-dark .CodeMirror-activeline-background { background: #<%= @base["02"]["hex"] %>;}
