# ~/.bspwm/bspwmrc
# bspwm config template
# Base16 <%- scheme %> by <%- author %>
# template by Luke Jones @luke-nukem

bspc config active_border_color \#<%- base["04"]["hex"] %>
bspc config normal_border_color \#<%- base["02"]["hex"] %>
bspc config focused_border_color \#<%- base["08"]["hex"] %>
bspc config presel_feedback_color \#<%- base["08"]["hex"] %>
bspc config normal_locked_border_color \#<%- base["0B"]["hex"] %>
bspc config focused_locked_border_color \#<%- base["0B"]["hex"] %>
bspc config normal_sticky_border_color \#<%- base["09"]["hex"] %>
bspc config focused_sticky_border_color \#<%- base["09"]["hex"] %>
bspc config normal_private_border_color \#<%- base["01"]["hex"] %>
bspc config focused_private_border_color \#<%- base["01"]["hex"] %>
