<?xml version="1.0" encoding="UTF-8"?>
<style-scheme version="1.0" name="Base 16 <%- scheme %> Light">

  <!-- main colors, skipping one of attributes (backgroud/foreground) will use color from here -->
  <style name="Text" foreground="#<%- base["02"]["hex"] %>" background="#<%- base["07"]["hex"] %>"/>

  <!-- it will be underlined by default -->
  <style name="Link"/>

  <!-- selection, current line, search, matching brackets -->
  <style name="Selection" background="#<%- base["03"]["hex"] %>"/>
  <style name="CurrentLine" background="#<%- base["04"]["hex"] %>"/>
  <style name="LineNumber" foreground="#<%- base["04"]["hex"] %>"/>
  <style name="CurrentLineNumber" foreground="#<%- base["03"]["hex"] %>" bold="true"/>
  <style name="SearchResult" background="<%- base["06"]["hex"] %>"/>
  <style name="Parentheses" background="#<%- base["05"]["hex"] %>" />

  <!-- Selection whilst searching in it -->
  <style name="SearchScope" foreground="#<%- base["00"]["hex"] %>" background="#<%- base["04"]["hex"] %>"/>

  <!-- word (symbol) under cursor: background - color of marking frame, foreground - ignored -->
  <style name="Occurrences" background="#<%- base["04"]["hex"] %>"/>
  <style name="Occurrences.Rename" background="#<%- base["03"]["hex"] %>"/>
  <!-- unused variable: foreground - color of underlining -->
  <style name="Occurrences.Unused" foreground="#<%- base["09"]["hex"] %>"/>

  <!-- language primitives -->
  <style name="Number" foreground="#<%- base["09"]["hex"] %>"/>
  <style name="String" foreground="#<%- base["0B"]["hex"] %>"/>
  <style name="Keyword" foreground="#<%- base["0E"]["hex"] %>"/>
  <style name="Operator" foreground="#<%- base["02"]["hex"] %>"/>
  <style name="Preprocessor" foreground="#<%- base["0D"]["hex"] %>"/>
  <style name="Label" foreground="#<%- base["08"]["hex"] %>"/>

  <!-- types, classes -->
  <style name="Type" foreground="#<%- base["0A"]["hex"] %>"/>

  <!-- functions, methods -->
  <style name="Function" foreground="#<%- base["0D"]["hex"] %>"/>
  <style name="VirtualMethod" foreground="#<%- base["0D"]["hex"] %>" italic="true"/>

  <!-- variables -->
  <style name="Field" foreground="#<%- base["01"]["hex"] %>"/>
  <style name="Local" foreground="#<%- base["02"]["hex"] %>"/>
  <style name="Static" foreground="#<%- base["02"]["hex"] %>"/>
  <style name="JsScopeVar" foreground="#<%- base["02"]["hex"] %>" italic="true"/>
  <style name="JsImportVar" foreground="#<%- base["02"]["hex"] %>" italic="true"/>
  <style name="JsGlobalVar" foreground="#<%- base["02"]["hex"] %>" italic="true"/>

  <!-- whitespace -->
  <style name="VisualWhitespace" foreground="#<%- base["05"]["hex"] %>"/>

  <!-- comments -->
  <style name="Comment" foreground="#<%- base["04"]["hex"] %>"/>
  <style name="DisabledCode" foreground="#<%- base["04"]["hex"] %>"/>
  <style name="Doxygen.Comment" foreground="#<%- base["04"]["hex"] %>"/>
  <style name="Doxygen.Tag" foreground="#<%- base["04"]["hex"] %>"/>

  <!-- QML -->
  <style name="QmlTypeId" foreground="#<%- base["0E"]["hex"] %>"/>
  <style name="Binding" foreground="#<%- base["08"]["hex"] %>"/>
  <style name="QmlExternalId" foreground="#<%- base["0D"]["hex"] %>" italic="true"/>
  <style name="QmlExternalObjectProperty" foreground="#<%- base["0D"]["hex"] %>" italic="true"/>
  <style name="QmlLocalId" italic="true"/>
  <style name="QmlRootObjectProperty" italic="true"/>
  <style name="QmlScopeObjectProperty" italic="true"/>
  <style name="QmlStateName" italic="true"/>

  <!-- inline diff -->
  <style name="DiffFile" foreground="#<%- base["0E"]["hex"] %>"/>
  <style name="DiffLocation" foreground="#<%- base["0D"]["hex"] %>"/>
  <style name="AddedLine" foreground="#<%- base["0B"]["hex"] %>"/>
  <style name="RemovedLine" foreground="#<%- base["0A"]["hex"] %>"/>

  <!-- side-by-side diff -->
  <style name="DiffFileLine" foreground="#<%- base["0E"]["hex"] %>"/>
  <style name="DiffContextLine" foreground="#<%- base["0D"]["hex"] %>"/>
  <style name="DiffSourceLine" foreground="#<%- base["0B"]["hex"] %>"/>
  <style name="DiffSourceChar" foreground="#<%- base["0A"]["hex"] %>" background="#<%- base["06"]["hex"] %>"/>
  <style name="DiffDestLine" foreground="#<%- base["0B"]["hex"] %>"/>
  <style name="DiffDestChar" foreground="#<%- base["0A"]["hex"] %>" background="#<%- base["06"]["hex"] %>"/>
</style-scheme>
