// Atom template by Jan T. Sott (https://github.com/idleberg/)
// Base16 scheme and Base16 Builder by Chris Kempson (https://github.com/chriskempson)

// This defines all syntax variables that syntax themes must implement when they
// include a syntax-variables.less file.

// General colors
@syntax-text-color: #<%- base["05"]["hex"] %>;
@syntax-cursor-color: #<%- base["05"]["hex"] %>;
@syntax-selection-color: #<%- base["02"]["hex"] %>;
@syntax-background-color: #<%- base["00"]["hex"] %>;

// Guide colors
@syntax-wrap-guide-color: #<%- base["03"]["hex"] %>;
@syntax-indent-guide-color: #<%- base["03"]["hex"] %>;
@syntax-invisible-character-color: #<%- base["03"]["hex"] %>;

// For find and replace markers
@syntax-result-marker-color: #<%- base["03"]["hex"] %>;
@syntax-result-marker-color-selected: #<%- base["05"]["hex"] %>;

// Gutter colors
@syntax-gutter-text-color: #<%- base["05"]["hex"] %>;
@syntax-gutter-text-color-selected: #<%- base["05"]["hex"] %>;
@syntax-gutter-background-color: #<%- base["00"]["hex"] %>;
@syntax-gutter-background-color-selected: rgba(80, 80, 80, 0.33);

// For git diff info. i.e. in the gutter
// These are static and were not extracted from your textmate theme
@syntax-color-renamed: #<%- base["0D"]["hex"] %>;
@syntax-color-added: #<%- base["0B"]["hex"] %>;
@syntax-color-modified: #<%- base["0A"]["hex"] %>;
@syntax-color-removed: #<%- base["08"]["hex"] %>;
