{#
# Pantheon Terminal Template
# Charles B Johnson (http://cbjohnson.info)

#}#!/usr/bin/env bash
# Base16 <%- scheme %> - Pantheon Terminal color scheme install script
# <%- author %>
# Charles B Johnson (https://github.com/charlesbjohnson)

SCHEMA="org.pantheon.terminal.settings"

gsettings set "$SCHEMA" background "#<%- base["07"]["hex"] %>"
gsettings set "$SCHEMA" foreground "#<%- base["02"]["hex"] %>"
gsettings set "$SCHEMA" palette "#<%- base["07"]["hex"] %>:#<%- base["08"]["hex"] %>:#<%- base["0B"]["hex"] %>:#<%- base["0A"]["hex"] %>:#<%- base["0D"]["hex"] %>:#<%- base["0E"]["hex"] %>:#<%- base["0C"]["hex"] %>:#<%- base["05"]["hex"] %>:#<%- base["03"]["hex"] %>:#<%- base["08"]["hex"] %>:#<%- base["0B"]["hex"] %>:#<%- base["0A"]["hex"] %>:#<%- base["0D"]["hex"] %>:#<%- base["0E"]["hex"] %>:#<%- base["0C"]["hex"] %>:#<%- base["00"]["hex"] %>"
gsettings set "$SCHEMA" cursor-color "#<%- base["00"]["hex"] %>"

unset SCHEMA
