{#
# zathurarc-dark
#}

set default-bg                  "#<%- base["00"]["hex"] %>"
set default-fg                  "#<%- base["01"]["hex"] %>"

set statusbar-fg                "#<%- base["04"]["hex"] %>"
set statusbar-bg                "#<%- base["01"]["hex"] %>"

set inputbar-bg                 "#<%- base["00"]["hex"] %>"
set inputbar-fg                 "#<%- base["05"]["hex"] %>"

set notification-error-bg       "#<%- base["08"]["hex"] %>"
set notification-error-fg       "#<%- base["00"]["hex"] %>"

set notification-warning-bg     "#<%- base["08"]["hex"] %>"
set notification-warning-fg     "#<%- base["00"]["hex"] %>"

set highlight-color             "#<%- base["0A"]["hex"] %>"
set highlight-active-color      "#<%- base["0D"]["hex"] %>"

set index-active-bg             "#<%- base["0D"]["hex"] %>"

set completion-highlight-fg     "#<%- base["02"]["hex"] %>"
set completion-highlight-bg     "#<%- base["0C"]["hex"] %>"

set completion-bg               "#<%- base["02"]["hex"] %>"
set completion-fg               "#<%- base["0C"]["hex"] %>"

set notification-bg             "#<%- base["0B"]["hex"] %>"
set notification-fg             "#<%- base["00"]["hex"] %>"

set recolor-lightcolor          "#<%- base["00"]["hex"] %>"
set recolor-darkcolor           "#<%- base["06"]["hex"] %>"
set recolor                     "true"

# setting recolor-keep true will keep any color your pdf has.
# if it is false, it'll just be black and white
set recolor-keephue             "true"

# Rest of your configs go here:
