/*

    Name:       Base16 <%- scheme %> Light
    Author:     <%- author %>

    Prettify template by Jan T. Sott (https://github.com/idleberg/)
    Original Base16 color scheme by Chris Kempson (https://github.com/chriskempson/base16)

*/

/* plain text */
.pln {
  color: #<%- base["00"]["hex"] %>;
}

@media screen {
  /* string content */
  .str {
    color: #<%- base["0B"]["hex"] %>;
  }

  /* a keyword */
  .kwd {
    color: #<%- base["0E"]["hex"] %>;
  }

  /* a comment */
  .com {
    color: #<%- base["04"]["hex"] %>;
  }

  /* a type name */
  .typ {
    color: #<%- base["0D"]["hex"] %>;
  }

  /* a literal value */
  .lit {
    color: #<%- base["09"]["hex"] %>;
  }

  /* punctuation */
  .pun {
    color: #<%- base["00"]["hex"] %>;
  }

  /* lisp open bracket */
  .opn {
    color: #<%- base["00"]["hex"] %>;
  }

  /* lisp close bracket */
  .clo {
    color: #<%- base["00"]["hex"] %>;
  }

  /* a markup tag name */
  .tag {
    color: #<%- base["08"]["hex"] %>;
  }

  /* a markup attribute name */
  .atn {
    color: #<%- base["09"]["hex"] %>;
  }

  /* a markup attribute value */
  .atv {
    color: #<%- base["0C"]["hex"] %>;
  }

  /* a declaration */
  .dec {
    color: #<%- base["09"]["hex"] %>;
  }

  /* a variable name */
  .var {
    color: #<%- base["08"]["hex"] %>;
  }

  /* a function name */
  .fun {
    color: #<%- base["0D"]["hex"] %>;
  }
}
/* Use higher contrast and text-weight for printable form. */
@media print, projection {
  .str {
    color: #006600;
  }

  .kwd {
    color: #006;
    font-weight: bold;
  }

  .com {
    color: #600;
    font-style: italic;
  }

  .typ {
    color: #404;
    font-weight: bold;
  }

  .lit {
    color: #004444;
  }

  .pun, .opn, .clo {
    color: #444400;
  }

  .tag {
    color: #006;
    font-weight: bold;
  }

  .atn {
    color: #440044;
  }

  .atv {
    color: #006600;
  }
}
/* Style */
pre.prettyprint {
  background: #<%- base["07"]["hex"] %>;
  color: #<%- base["05"]["hex"] %>;
  font-family: Consolas, Menlo, "DejaVu Sans Mono", "Bitstream Vera Sans Mono", Monaco, monospace;
  font-size: 12px;
  line-height: 1.5;
  border: 1px solid #<%- base["06"]["hex"] %>;
  padding: 10px;
  border-radius: 3px;
}

/* Specify class=linenums on a pre to get line numbering */
ol.linenums {
  margin-top: 0;
  margin-bottom: 0;
}

/* IE indents via margin-left */
li.L0,
li.L1,
li.L2,
li.L3,
li.L4,
li.L5,
li.L6,
li.L7,
li.L8,
li.L9 {
  /* */
}

/* Alternate shading for lines */
li.L1,
li.L3,
li.L5,
li.L7,
li.L9 {
  /* */
}
