/*

    Name:       Base16 <%- scheme %> Light
    Author:     <%- author %>

    Prettify template by Jan T. Sott (https://github.com/idleberg/)
    Original Base16 color scheme by Chris Kempson (https://github.com/chriskempson/base16)

*/

$base00 = #<%- base["00"]["hex"] %>;
$base01 = #<%- base["01"]["hex"] %>;
$base02 = #<%- base["02"]["hex"] %>;
$base03 = #<%- base["03"]["hex"] %>;
$base04 = #<%- base["04"]["hex"] %>;
$base05 = #<%- base["05"]["hex"] %>;
$base06 = #<%- base["06"]["hex"] %>;
$base07 = #<%- base["07"]["hex"] %>;
$base08 = #<%- base["08"]["hex"] %>;
$base09 = #<%- base["09"]["hex"] %>;
$base0a = #<%- base["0A"]["hex"] %>;
$base0b = #<%- base["0B"]["hex"] %>;
$base0c = #<%- base["0C"]["hex"] %>;
$base0d = #<%- base["0D"]["hex"] %>;
$base0e = #<%- base["0E"]["hex"] %>;
$base0f = #<%- base["0F"]["hex"] %>;

// plain text
.pln {
  color: $base00;
}

@media screen {
  // string content
  .str {
    color: $base0b;
  }

  // a keyword
  .kwd {
    color: $base0e;
  }

  // a comment
  .com {
    color: $base04;
  }

  // a type name
  .typ {
    color: $base0d;
  }

  // a literal value
  .lit {
    color: $base09;
  }

  // punctuation
  .pun {
    color: $base00;
  }

  // lisp open bracket
  .opn {
    color: $base00;
  }

  // lisp close bracket
  .clo {
    color: $base00;
  }

  // a markup tag name
  .tag {
    color: $base08;
  }

  // a markup attribute name
  .atn {
    color: $base09;
  }

  // a markup attribute value
  .atv {
    color: $base0c;
  }

  // a declaration
  .dec {
    color: $base09;
  }

  // a variable name
  .var {
    color: $base08;
  }

  // a function name
  .fun {
    color: $base0d;
  }
}
// Use higher contrast and text-weight for printable form.
@media print, projection {
  .str {
    color: #006600;
  }

  .kwd {
    color: #006;
    font-weight: bold;
  }

  .com {
    color: #600;
    font-style: italic;
  }

  .typ {
    color: #404;
    font-weight: bold;
  }

  .lit {
    color: #004444;
  }

  .pun, .opn, .clo {
    color: #444400;
  }

  .tag {
    color: #006;
    font-weight: bold;
  }

  .atn {
    color: #440044;
  }

  .atv {
    color: #006600;
  }
}
// Style
pre.prettyprint {
  background: $base07;
  font-family: Menlo, "Bitstream Vera Sans Mono", "DejaVu Sans Mono", Monaco, Consolas, monospace;
  font-size: 12px;
  line-height: 1.5;
  border: 1px solid $base00;
  padding: 10px;
}

// Specify class=linenums on a pre to get line numbering
ol.linenums {
  margin-top: 0;
  margin-bottom: 0;
}

// IE indents via margin-left
li.L0,
li.L1,
li.L2,
li.L3,
li.L4,
li.L5,
li.L6,
li.L7,
li.L8,
li.L9 {
}

// Alternate shading for lines
li.L1,
li.L3,
li.L5,
li.L7,
li.L9 {
}
