# vim: filetype=yaml
# i3-style Template
# Base16 <%- scheme %>, by <%- author %>
# template by Matt Parnell, @parnmatt
---
colors:
    base00:              '#<%- base["00"]["hex"] %>'
    base01:              '#<%- base["01"]["hex"] %>'
    base02:              '#<%- base["02"]["hex"] %>'
    base03:              '#<%- base["03"]["hex"] %>'
    base04:              '#<%- base["04"]["hex"] %>'
    base05:              '#<%- base["05"]["hex"] %>'
    base06:              '#<%- base["06"]["hex"] %>'
    base07:              '#<%- base["07"]["hex"] %>'
    base08:              '#<%- base["08"]["hex"] %>'
    base09:              '#<%- base["09"]["hex"] %>'
    base0A:              '#<%- base["0A"]["hex"] %>'
    base0B:              '#<%- base["0B"]["hex"] %>'
    base0C:              '#<%- base["0C"]["hex"] %>'
    base0D:              '#<%- base["0D"]["hex"] %>'
    base0E:              '#<%- base["0E"]["hex"] %>'
    base0F:              '#<%- base["0F"]["hex"] %>'

meta:
    description:         'Base16 <%- scheme %>, by <%- author %>'
window_colors:
    focused:
        border:          'base0D'
        background:      'base0D'
        text:            'base00'
        indicator:       'base01'
    focused_inactive:
        border:          'base02'
        background:      'base02'
        text:            'base03'
        indicator:       'base01'
    unfocused:
        border:          'base01'
        background:      'base01'
        text:            'base03'
        indicator:       'base01'
    urgent:
        border:          'base02'
        background:      'base08'
        text:            'base07'
        indicator:       'base08'
bar_colors:
    separator:           'base03'
    background:          'base00'
    statusline:          'base05'
    focused_workspace:
        border:          'base0D'
        background:      'base0D'
        text:            'base00'
    active_workspace:
        border:          'base02'
        background:      'base02'
        text:            'base07'
    inactive_workspace:
        border:          'base01'
        background:      'base01'
        text:            'base03'
    urgent_workspace:
        border:          'base08'
        background:      'base08'
        text:            'base07'
