/*

    Name:       Base16 <%- scheme %> Light
    Author:     <%- author %>

    highlight.js v8.0 template by Jan T. Sott (https://github.com/idleberg/base16-highlight.js)
    Original Base16 color scheme by Chris Kempson (https://github.com/chriskempson/base16)

*/

/* <%- scheme %> Comment */
.hljs-comment {
  color: #<%- base["03"]["hex"] %>;
}

/* <%- scheme %> Red */
.hljs-variable,
.hljs-attribute,
.hljs-tag,
.hljs-regexp,
.hljs-name,
.ruby .hljs-constant,
.xml .hljs-tag .hljs-title,
.xml .hljs-pi,
.xml .hljs-doctype,
.html .hljs-doctype,
.css .hljs-id,
.css .hljs-class,
.css .hljs-pseudo {
  color: #<%- base["08"]["hex"] %>;
}

/* <%- scheme %> Orange */
.hljs-number,
.hljs-preprocessor,
.hljs-built_in,
.hljs-literal,
.hljs-params,
.hljs-constant {
  color: #<%- base["09"]["hex"] %>;
}

/* <%- scheme %> Yellow */
.ruby .hljs-class .hljs-title,
.css .hljs-rule .hljs-attribute {
  color: #<%- base["0A"]["hex"] %>;
}

/* <%- scheme %> Green */
.hljs-string,
.hljs-value,
.hljs-inheritance,
.hljs-header,
.ruby .hljs-symbol,
.xml .hljs-cdata {
  color: #<%- base["0B"]["hex"] %>;
}

/* <%- scheme %> Aqua */
.hljs-title,
.css .hljs-hexcolor {
  color: #<%- base["0C"]["hex"] %>;
}

/* <%- scheme %> Blue */
.hljs-function,
.python .hljs-decorator,
.python .hljs-title,
.ruby .hljs-function .hljs-title,
.ruby .hljs-title .hljs-keyword,
.perl .hljs-sub,
.javascript .hljs-title,
.coffeescript .hljs-title {
  color: #<%- base["0D"]["hex"] %>;
}

/* <%- scheme %> Purple */
.hljs-keyword,
.javascript .hljs-function {
  color: #<%- base["0E"]["hex"] %>;
}

.diff .hljs-deletion,
.diff .hljs-addition {
  color: #<%- base["00"]["hex"] %>;
  display: inline-block;
  width: 100%;
}
.diff .hljs-deletion {
  background-color: #<%- base["08"]["hex"] %>;
}
.diff .hljs-addition {
  background-color: #<%- base["0B"]["hex"] %>;
}
.diff .hljs-change {
  color: #<%- base["0D"]["hex"] %>;
}

.hljs {
  display: block;
  overflow-x: auto;
  background: #<%- base["07"]["hex"] %>;
  color: #<%- base["02"]["hex"] %>;
  padding: 0.5em;
  -webkit-text-size-adjust: none;
}

.coffeescript .javascript,
.javascript .xml,
.tex .hljs-formula,
.xml .javascript,
.xml .vbscript,
.xml .css,
.xml .hljs-cdata {
  opacity: 0.5;
}
