<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
  <key>DVTConsoleDebuggerInputTextColor</key>
  <string><%- [].concat.apply(base['05']['srgb'], [1]).join(' ') %></string>
  <key>DVTConsoleDebuggerInputTextFont</key>
  <string>Menlo-Bold - 11.0</string>
  <key>DVTConsoleDebuggerOutputTextColor</key>
  <string><%- [].concat.apply(base['05']['srgb'], [1]).join(' ') %></string>
  <key>DVTConsoleDebuggerOutputTextFont</key>
  <string>Menlo-Regular - 11.0</string>
  <key>DVTConsoleDebuggerPromptTextColor</key>
  <string><%- [].concat.apply(base['0D']['srgb'], [1]).join(' ') %></string>
  <key>DVTConsoleDebuggerPromptTextFont</key>
  <string>Menlo-Bold - 11.0</string>
  <key>DVTConsoleExectuableInputTextColor</key>
  <string><%- [].concat.apply(base['05']['srgb'], [1]).join(' ') %></string>
  <key>DVTConsoleExectuableInputTextFont</key>
  <string>Menlo-Regular - 11.0</string>
  <key>DVTConsoleExectuableOutputTextColor</key>
  <string><%- [].concat.apply(base['05']['srgb'], [1]).join(' ') %></string>
  <key>DVTConsoleExectuableOutputTextFont</key>
  <string>Menlo-Bold - 11.0</string>
  <key>DVTConsoleTextBackgroundColor</key>
  <string><%- [].concat.apply(base['00']['srgb'], [1]).join(' ') %></string>
  <key>DVTConsoleTextInsertionPointColor</key>
  <string><%- [].concat.apply(base['05']['srgb'], [1]).join(' ') %></string>
  <key>DVTConsoleTextSelectionColor</key>
  <string><%- [].concat.apply(base['02']['srgb'], [1]).join(' ') %></string>
  <key>DVTDebuggerInstructionPointerColor</key>
  <string><%- [].concat.apply(base['0B']['srgb'], [1]).join(' ') %></string>
  <key>DVTSourceTextBackground</key>
  <string><%- [].concat.apply(base['00']['srgb'], [1]).join(' ') %></string>
  <key>DVTSourceTextBlockDimBackgroundColor</key>
  <string>0.5 0.5 0.5 1</string>
  <key>DVTSourceTextInsertionPointColor</key>
  <string><%- [].concat.apply(base['05']['srgb'], [1]).join(' ') %></string>
  <key>DVTSourceTextInvisiblesColor</key>
  <string><%- [].concat.apply(base['03']['srgb'], [1]).join(' ') %></string>
  <key>DVTSourceTextSelectionColor</key>
  <string><%- [].concat.apply(base['02']['srgb'], [1]).join(' ') %></string>
  <key>DVTSourceTextSyntaxColors</key>
  <dict>
    <key>xcode.syntax.attribute</key>
    <string><%- [].concat.apply(base['0E']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.character</key>
    <string><%- [].concat.apply(base['0B']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.comment</key>
    <string><%- [].concat.apply(base['03']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.comment.doc</key>
    <string><%- [].concat.apply(base['03']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.comment.doc.keyword</key>
    <string><%- [].concat.apply(base['06']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.identifier.class</key>
    <string><%- [].concat.apply(base['09']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.identifier.class.system</key>
    <string><%- [].concat.apply(base['09']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.identifier.constant</key>
    <string><%- [].concat.apply(base['0F']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.identifier.constant.system</key>
    <string><%- [].concat.apply(base['0F']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.identifier.function</key>
    <string><%- [].concat.apply(base['0A']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.identifier.function.system</key>
    <string><%- [].concat.apply(base['09']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.identifier.macro</key>
    <string><%- [].concat.apply(base['0F']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.identifier.macro.system</key>
    <string><%- [].concat.apply(base['0F']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.identifier.type</key>
    <string><%- [].concat.apply(base['08']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.identifier.type.system</key>
    <string><%- [].concat.apply(base['09']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.identifier.variable</key>
    <string><%- [].concat.apply(base['08']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.identifier.variable.system</key>
    <string><%- [].concat.apply(base['08']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.keyword</key>
    <string><%- [].concat.apply(base['0D']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.number</key>
    <string><%- [].concat.apply(base['0B']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.plain</key>
    <string><%- [].concat.apply(base['07']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.preprocessor</key>
    <string><%- [].concat.apply(base['0C']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.string</key>
    <string><%- [].concat.apply(base['0B']['srgb'], [1]).join(' ') %></string>
    <key>xcode.syntax.url</key>
    <string><%- [].concat.apply(base['0E']['srgb'], [1]).join(' ') %></string>
  </dict>
  <key>DVTSourceTextSyntaxFonts</key>
  <dict>
    <key>xcode.syntax.attribute</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.character</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.comment</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.comment.doc</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.comment.doc.keyword</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.identifier.class</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.identifier.class.system</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.identifier.constant</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.identifier.constant.system</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.identifier.function</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.identifier.function.system</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.identifier.macro</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.identifier.macro.system</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.identifier.type</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.identifier.type.system</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.identifier.variable</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.identifier.variable.system</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.keyword</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.number</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.plain</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.preprocessor</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.string</key>
    <string>Menlo-Regular - 11.0</string>
    <key>xcode.syntax.url</key>
    <string>Menlo-Regular - 11.0</string>
  </dict>
</dict>
</plist>
