/*

Name:       Base16 <%- scheme %> Dark
Author:     <%- author %>

Prism template by Bram de Haan (http://atelierbram.github.io/syntax-highlighting/prism/)
Original Base16 color scheme by Chris Kempson (https://github.com/chriskempson/base16)

*/

code[class*="language-"],
pre[class*="language-"] {
  font-family: Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace;
  font-size: 14px;
  line-height: 1.375;
  direction: ltr;
  text-align: left;
  white-space: pre;
  word-spacing: normal;
  word-break: normal;

  -moz-tab-size: 4;
  -o-tab-size: 4;
  tab-size: 4;

  -webkit-hyphens: none;
  -moz-hyphens: none;
  -ms-hyphens: none;
  hyphens: none;
  background: #<%- base["00"]["hex"] %>;
  color: #<%- base["05"]["hex"] %>;
}

pre[class*="language-"]::-moz-selection, pre[class*="language-"] ::-moz-selection,
code[class*="language-"]::-moz-selection, code[class*="language-"] ::-moz-selection {
  text-shadow: none;
  background: #<%- base["04"]["hex"] %>;
}

pre[class*="language-"]::selection, pre[class*="language-"] ::selection,
code[class*="language-"]::selection, code[class*="language-"] ::selection {
  text-shadow: none;
  background: #<%- base["04"]["hex"] %>;
}

/* Code blocks */
pre[class*="language-"] {
  padding: 1em;
  margin: .5em 0;
  overflow: auto;
}

/* Inline code */
:not(pre) > code[class*="language-"] {
  padding: .1em;
  border-radius: .3em;
}

.token.comment,
.token.prolog,
.token.doctype,
.token.cdata {
  color: #<%- base["03"]["hex"] %>;
}

.token.punctuation {
  color: #<%- base["05"]["hex"] %>;
}

.token.namespace {
  opacity: .7;
}

.token.operator,
.token.boolean,
.token.number {
  color: #<%- base["09"]["hex"] %>;
}
.token.property {
  color: #<%- base["0A"]["hex"] %>;
}
.token.tag {
  color: #<%- base["0D"]["hex"] %>;
}
.token.string {
  color: #<%- base["0C"]["hex"] %>;
}
.token.selector {
  color: #<%- base["0E"]["hex"] %>;
}
.token.attr-name {
  color: #<%- base["09"]["hex"] %>;
}
.token.entity,
.token.url,
.language-css .token.string,
.style .token.string {
  color: #<%- base["0C"]["hex"] %>;
}

.token.attr-value,
.token.keyword,
.token.control,
.token.directive,
.token.unit {
  color: #<%- base["0B"]["hex"] %>;
}

.token.statement,
.token.regex,
.token.atrule {
  color: #<%- base["0C"]["hex"] %>;
}

.token.placeholder,
.token.variable {
  color: #<%- base["0D"]["hex"] %>;
}

.token.deleted {
  text-decoration: line-through;
}

.token.inserted {
  border-bottom: 1px dotted #<%- base["07"]["hex"] %>;
  text-decoration: none;
}

.token.italic {
  font-style: italic;
}

.token.important,
.token.bold {
  font-weight: bold;
}

.token.important {
  color: #<%- base["08"]["hex"] %>;
}

.token.entity {
  cursor: help;
}

pre > code.highlight {
  outline: .4em solid #<%- base["08"]["hex"] %>;
  outline-offset: .4em;
}

/* overrides color-values for the Line Numbers plugin
 * http://prismjs.com/plugins/line-numbers/
 */
.line-numbers .line-numbers-rows {
  border-right-color: #<%- base["01"]["hex"] %>;
}

.line-numbers-rows > span:before {
  color: #<%- base["02"]["hex"] %>;
}

/* overrides color-values for the Line Highlight plugin
 * http://prismjs.com/plugins/line-highlight/
 * alpha transparency in 8 digits hex notation coming to a browser near you soon:
 * https://drafts.csswg.org/css-color/#hex-notation
 */
.line-highlight {
  background: #<%- base["05"]["hex"] %>33;
  background: linear-gradient(to right, #<%- base["05"]["hex"] %>33 70%, #<%- base["05"]["hex"] %>00);
}
